package technology.tabula;

import static org.junit.Assert.*;

import java.io.IOException;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

import junit.framework.Assert;

import org.junit.Test;

import technology.tabula.Page;
import technology.tabula.Ruling;
import technology.tabula.Table;
import technology.tabula.extractors.BasicExtractionAlgorithm;
import technology.tabula.writers.CSVWriter;
import technology.tabula.UtilsForTesting;

public class TestBasicExtractor {

    private static final String[][] EXPECTED_CORRECT_COLUMNS = {
            { "", "", "Involvement of pupils in ", "" },
            { "", "Preperation and ", "Production of ", "Presentation an" },
            { "", "planing ", "materials ", "evaluation " },
            { "Knowledge and awareness of different cultures ", "0,2885 ",
                    "0,3974 ", "0,3904 " },
            { "Foreign language competence ", "0,3057 ", "0,4184 ", "0,3899 " },
            { "Social skills and abilities ", "0,3416 ", "0,3369 ", "0,4303 " },
            { "Acquaintance of special knowledge ", "0,2569 ", "0,2909 ",
                    "0,3557 " },
            { "Self competence ", "0,3791 ", "0,3320 ", "0,4617 " } };

    private static final String[][] EXPECTED_COLUMN_RECOGNITION = {
            { "ABDALA de MATARAZZO, Norma Amanda ",
                    "Frente Cívico por Santiago ", "Santiago del Estero ",
                    "AFIRMATIVO" },
            { "ALBRIEU, Oscar Edmundo Nicolas ",
                    "Frente para la Victoria - PJ ", "Rio Negro ", "AFIRMATIVO" },
            { "ALONSO, María Luz ", "Frente para la Victoria - PJ ",
                    "La Pampa ", "AFIRMATIVO" },
            { "ARENA, Celia Isabel ", "Frente para la Victoria - PJ ",
                    "Santa Fe ", "AFIRMATIVO" },
            { "ARREGUI, Andrés Roberto ", "Frente para la Victoria - PJ ",
                    "Buenos Aires ", "AFIRMATIVO" },
            { "AVOSCAN, Herman Horacio ", "Frente para la Victoria - PJ ",
                    "Rio Negro ", "AFIRMATIVO" },
            { "BALCEDO, María Ester ", "Frente para la Victoria - PJ ",
                    "Buenos Aires ", "AFIRMATIVO" },
            { "BARRANDEGUY, Raúl Enrique ", "Frente para la Victoria - PJ ",
                    "Entre Ríos ", "AFIRMATIVO" },
            { "BASTERRA, Luis Eugenio ", "Frente para la Victoria - PJ ",
                    "Formosa ", "AFIRMATIVO" },
            { "BEDANO, Nora Esther ", "Frente para la Victoria - PJ ",
                    "Córdoba ", "AFIRMATIVO" },
            { "BERNAL, María Eugenia ", "Frente para la Victoria - PJ ",
                    "Jujuy ", "AFIRMATIVO" },
            { "BERTONE, Rosana Andrea ", "Frente para la Victoria - PJ ",
                    "Tierra del Fuego ", "AFIRMATIVO" },
            { "BIANCHI, María del Carmen ", "Frente para la Victoria - PJ ",
                    "Cdad. Aut. Bs. As. ", "AFIRMATIVO" },
            { "BIDEGAIN, Gloria Mercedes ", "Frente para la Victoria - PJ ",
                    "Buenos Aires ", "AFIRMATIVO" },
            { "BRAWER, Mara ", "Frente para la Victoria - PJ ",
                    "Cdad. Aut. Bs. As. ", "AFIRMATIVO" },
            { "BRILLO, José Ricardo ", "Movimiento Popular Neuquino ",
                    "Neuquén ", "AFIRMATIVO" },
            { "BROMBERG, Isaac Benjamín ", "Frente para la Victoria - PJ ",
                    "Tucumán ", "AFIRMATIVO" },
            { "BRUE, Daniel Agustín ", "Frente Cívico por Santiago ",
                    "Santiago del Estero ", "AFIRMATIVO" },
            { "CALCAGNO, Eric ", "Frente para la Victoria - PJ ",
                    "Buenos Aires ", "AFIRMATIVO" },
            { "CARLOTTO, Remo Gerardo ", "Frente para la Victoria - PJ ",
                    "Buenos Aires ", "AFIRMATIVO" },
            { "CARMONA, Guillermo Ramón ", "Frente para la Victoria - PJ ",
                    "Mendoza ", "AFIRMATIVO" },
            { "CATALAN MAGNI, Julio César ", "Frente para la Victoria - PJ ",
                    "Tierra del Fuego ", "AFIRMATIVO" },
            { "CEJAS, Jorge Alberto ", "Frente para la Victoria - PJ ",
                    "Rio Negro ", "AFIRMATIVO" },
            { "CHIENO, María Elena ", "Frente para la Victoria - PJ ",
                    "Corrientes ", "AFIRMATIVO" },
            { "CIAMPINI, José Alberto ", "Frente para la Victoria - PJ ",
                    "Neuquén ", "AFIRMATIVO" },
            { "CIGOGNA, Luis Francisco Jorge ",
                    "Frente para la Victoria - PJ ", "Buenos Aires ",
                    "AFIRMATIVO" },
            { "CLERI, Marcos ", "Frente para la Victoria - PJ ", "Santa Fe ",
                    "AFIRMATIVO" },
            { "COMELLI, Alicia Marcela ", "Movimiento Popular Neuquino ",
                    "Neuquén ", "AFIRMATIVO" },
            { "CONTI, Diana Beatriz ", "Frente para la Victoria - PJ ",
                    "Buenos Aires ", "AFIRMATIVO" },
            { "CORDOBA, Stella Maris ", "Frente para la Victoria - PJ ",
                    "Tucumán ", "AFIRMATIVO" },
            { "CURRILEN, Oscar Rubén ", "Frente para la Victoria - PJ ",
                    "Chubut ", "AFIRMATIVO" } };
    
    private static final String[][] EXPECTED_COLUMN_EXTRACTION2 = {
        {"","Austria","77","1","78"},
        {"","Belgium","159","2","161"},
        {"","Bulgaria","52","0","52"},
        {"","Croatia","144","0","144"},
        {"","Cyprus","43","2","45"},
        {"","Czech Republic","78","0","78"},
        {"","Denmark","151","2","153"},
        {"","Estonia","46","0","46"},
        {"","Finland","201","1","202"},
        {"","France","428","7","435"},
        {"","Germany","646","21","667"},
        {"","Greece","113","2","115"},
        {"","Hungary","187","0","187"},
        {"","Iceland","18","0","18"},
        {"","Ireland","213","4","217"},
        {"","Israel","25","0","25"},
        {"","Italy","627","12","639"},
        {"","Latvia","7","0","7"},
        {"","Lithuania","94","1","95"},
        {"","Luxembourg","22","0","22"},
        {"","Malta","18","0","18"},
        {"","Netherlands","104","1","105"},
        {"","Norway","195","0","195"},
        {"","Poland","120","1","121"},
        {"","Portugal","532","3","535"},
        {"","Romania","110","0","110"},
        {"","Slovakia","176","0","176"},
        {"","Slovenia","56","0","56"},
        {"","Spain","614","3","617"},
        {"","Sweden","122","3","125"},
        {"","Switzerland","64","0","64"},
        {"","Turkey","96","0","96"},
        {"","United Kingdom","572","14","586"}
    };
    
    private static final String[][] EXPECTED_TABLE_EXTRACTION = {
        {"AANONSEN, DEBORAH, A ","","","STATEN ISLAND, NY ","MEALS ","$85.00"},
        {"TOTAL ","","","","","$85.00"},
        {"AARON, CAREN, T ","","","RICHMOND, VA ","EDUCATIONAL ITEMS ","$78.80"},
        {"AARON, CAREN, T ","","","RICHMOND, VA ","MEALS ","$392.45"},
        {"TOTAL ","","","","","$471.25"},
        {"AARON, JOHN ","","","CLARKSVILLE, TN ","MEALS ","$20.39"},
        {"TOTAL ","","","","","$20.39"},
        {"AARON, JOSHUA, N ","","","WEST GROVE, PA ","MEALS ","$310.33"},
        {"AARON , JOSHUA , N ","REGIONAL PULMONARY & SLEEPMEDICINE ","","WEST GROVE, PA ","SPEAKING FEES ","$4,700.00"},
        {"TOTAL ","","","","","$5,010.33"},
        {"AARON, MAUREEN, M ","","","MARTINSVILLE, VA ","MEALS ","$193.67"},
        {"TOTAL ","","","","","$193.67"},
        {"AARON, MICHAEL, L ","","","WEST ISLIP, NY ","MEALS ","$19.50"},
        {"TOTAL ","","","","","$19.50"},
        {"AARON, MICHAEL, R ","","","BROOKLYN, NY ","MEALS ","$65.92"}
        };


    private static final Rectangle[] RECTANGLES_TEST_NATURAL_ORDER = {
            new Rectangle(38.368214f, 405.48f, 6.5260315f, 6.1515007f),
            new Rectangle(38.368214f, 412.02048f, 5.2577515f, 6.1515007f),
            new Rectangle(38.368214f, 417.3023f, 4.8965454f, 6.1515007f),
            new Rectangle(38.368214f, 422.26788f, 2.7211914f, 6.1515007f),
            new Rectangle(38.368214f, 425.0292f, 2.4161682f, 6.1515007f),
            new Rectangle(38.368214f, 427.5144f, 5.4825134f, 6.1515007f),
            new Rectangle(38.368214f, 432.97363f, 5.1935425f, 6.1515007f),
            new Rectangle(38.368214f, 438.2362f, 2.7211914f, 6.1515007f),
            new Rectangle(38.368214f, 440.93732f, 2.2235107f, 6.1515007f),
            new Rectangle(38.368214f, 443.15842f, 4.8965454f, 6.1515007f),
            new Rectangle(38.368214f, 448.124f, 4.8804626f, 6.1515007f),
            new Rectangle(38.368214f, 453.04462f, 7.529419f, 6.1515007f),
            new Rectangle(38.368214f, 460.60452f, 5.4744873f, 6.1515007f),
            new Rectangle(38.368214f, 466.18335f, 5.217621f, 6.1515007f),
            new Rectangle(38.368214f, 471.40417f, 2.4161682f, 6.1515007f),
            new Rectangle(38.368214f, 473.8661f, 2.2235107f, 6.1515007f),
            new Rectangle(38.368214f, 476.0872f, 4.01355f, 6.1515007f),
            new Rectangle(38.368214f, 480.10715f, 2.2235107f, 6.1515007f),
            new Rectangle(38.368214f, 482.38846f, 4.8724365f, 6.1515007f),
            new Rectangle(38.368214f, 487.32996f, 4.3025208f, 6.1515007f),
            new Rectangle(38.368214f, 491.7015f, 7.376892f, 6.1515007f),
            new Rectangle(38.368214f, 499.0816f, 2.2235107f, 6.1515007f),
            new Rectangle(38.368214f, 501.3629f, 4.4470215f, 6.1515007f),
            new Rectangle(38.368214f, 505.87897f, 4.4470215f, 6.1515007f),
            new Rectangle(38.368214f, 510.31717f, 2.2234802f, 6.1515007f),
            new Rectangle(49.408497f, 462.0598f, 2.2235107f, 6.1515007f),
            new Rectangle(49.408497f, 464.2809f, 3.893158f, 6.1515007f),
            new Rectangle(49.408497f, 468.1861f, 1.6054077f, 6.1515007f),
            new Rectangle(49.408497f, 469.80356f, 4.8965454f, 6.1515007f),
            new Rectangle(49.408497f, 474.78436f, 5.4825134f, 6.1515007f),
            new Rectangle(49.408497f, 480.2436f, 1.6054077f, 6.1515007f),
            new Rectangle(49.408497f, 481.92206f, 2.2235107f, 6.1515007f),
            new Rectangle(49.408497f, 484.14316f, 4.8724365f, 6.1515007f),
            new Rectangle(49.408497f, 489.02765f, 5.217621f, 6.1515007f),
            new Rectangle(49.408497f, 494.30865f, 5.4744873f, 6.1515007f),
            new Rectangle(49.408497f, 499.79517f, 5.2577515f, 6.1515007f),
            new Rectangle(49.408497f, 505.1372f, 2.4161682f, 6.1515007f),
            new Rectangle(49.408497f, 507.5654f, 2.7211914f, 6.1515007f),
            new Rectangle(49.408497f, 510.2986f, 2.2234802f, 6.1515007f),
            new Rectangle(793.4082f, 85.08f, 7.3170013f, 6.1515007f),
            new Rectangle(793.4082f, 92.3403f, 6.6600037f, 6.1515007f),
            new Rectangle(793.4082f, 99.1227f, 5.4629974f, 6.1515007f),
            new Rectangle(793.4082f, 104.58301f, 4.4820023f, 6.1515007f),
            new Rectangle(793.4082f, 109.022705f, 6.6600037f, 6.1515007f),
            new Rectangle(793.4082f, 115.744804f, 2.4930038f, 6.1515007f),
            new Rectangle(793.4082f, 437.04028f, 5.328003f, 6.1515007f),
            new Rectangle(793.4082f, 442.36377f, 6.147003f, 6.1515007f),
            new Rectangle(793.4082f, 448.50626f, 6.057007f, 6.1515007f),
            new Rectangle(793.4082f, 454.55875f, 5.850006f, 6.1515007f),
            new Rectangle(793.4082f, 460.40424f, 2.4930115f, 6.1515007f),
            new Rectangle(793.4082f, 462.92514f, 4.9859924f, 6.1515007f),
            new Rectangle(793.4082f, 467.90665f, 4.9859924f, 6.1515007f),
            new Rectangle(793.4082f, 472.88815f, 4.9859924f, 6.1515007f),
            new Rectangle(793.4082f, 477.86966f, 2.4930115f, 6.1515007f),
            new Rectangle(793.4082f, 480.39056f, 5.894989f, 6.1515007f),
            new Rectangle(793.4082f, 486.28107f, 2.8259888f, 6.1515007f),
            new Rectangle(793.4082f, 489.10257f, 2.4930115f, 6.1515007f),
            new Rectangle(793.4082f, 491.62347f, 4.9859924f, 6.1515007f),
            new Rectangle(793.4082f, 496.60498f, 4.9859924f, 6.1515007f),
            new Rectangle(793.4082f, 501.5865f, 4.9859924f, 6.1515007f),
            new Rectangle(793.4082f, 506.568f, 2.4930115f, 6.1515007f),
            new Rectangle(805.94824f, 510.3f, 2.492981f, 6.1515007f),
            new Rectangle(120.76954f, 155.28f, 5.7591705f, 5.5301404f),
            new Rectangle(120.76954f, 161.03598f, 4.873764f, 5.5301404f),
            new Rectangle(120.76954f, 165.90656f, 4.873764f, 5.5301404f),
            new Rectangle(120.76954f, 170.77713f, 4.873764f, 5.5301404f),
            new Rectangle(120.76954f, 175.6477f, 2.6562347f, 5.5301404f),
            new Rectangle(120.76954f, 178.30075f, 3.1029358f, 5.5301404f),
            new Rectangle(120.76954f, 181.4005f, 4.4350433f, 5.5301404f),
            new Rectangle(115.60969f, 217.92023f, 5.320465f, 5.5301404f),
            new Rectangle(115.60969f, 223.24467f, 4.4350433f, 5.5301404f),
            new Rectangle(115.60969f, 227.68372f, 2.2175293f, 5.5301404f),
            new Rectangle(115.60969f, 229.90523f, 2.2175293f, 5.5301404f),
            new Rectangle(115.60969f, 232.12674f, 4.873764f, 5.5301404f),
            new Rectangle(115.60969f, 237.00449f, 2.2175293f, 5.5301404f),
            new Rectangle(115.60969f, 239.226f, 3.1029358f, 5.5301404f),
            new Rectangle(115.60969f, 242.33292f, 4.4350433f, 5.5301404f),
            new Rectangle(115.60969f, 246.77196f, 4.873764f, 5.5301404f),
            new Rectangle(115.60969f, 251.6497f, 2.2175293f, 5.5301404f),
            new Rectangle(115.60969f, 253.87122f, 2.2175293f, 5.5301404f),
            new Rectangle(115.60969f, 256.0927f, 4.4350586f, 5.5301404f),
            new Rectangle(115.60969f, 260.53174f, 4.4350586f, 5.5301404f),
            new Rectangle(115.60969f, 264.97076f, 2.2175293f, 5.5301404f),
            new Rectangle(125.989265f, 219.60011f, 4.873764f, 5.5301404f),
            new Rectangle(125.989265f, 224.47467f, 4.4350433f, 5.5301404f),
            new Rectangle(125.989265f, 228.9105f, 3.1029358f, 5.5301404f),
            new Rectangle(125.989265f, 232.01424f, 2.2175293f, 5.5301404f),
            new Rectangle(125.989265f, 234.23575f, 4.4350433f, 5.5301404f),
            new Rectangle(125.989265f, 238.67159f, 4.873764f, 5.5301404f),
            new Rectangle(125.989265f, 243.54614f, 4.873764f, 5.5301404f),
            new Rectangle(125.989265f, 248.4207f, 4.873764f, 5.5301404f),
            new Rectangle(125.989265f, 253.29526f, 2.6562347f, 5.5301404f),
            new Rectangle(125.989265f, 255.9523f, 3.1029358f, 5.5301404f),
            new Rectangle(125.989265f, 259.05603f, 4.4350586f, 5.5301404f),
            new Rectangle(110.38917f, 285.3002f, 5.759186f, 5.5301404f),
            new Rectangle(110.38917f, 291.05618f, 4.873749f, 5.5301404f),
            new Rectangle(110.38917f, 295.92676f, 7.091278f, 5.5301404f),
            new Rectangle(110.38917f, 303.01486f, 4.873749f, 5.5301404f),
            new Rectangle(110.38917f, 307.88544f, 4.4350586f, 5.5301404f),
            new Rectangle(110.38917f, 312.3173f, 3.1029358f, 5.5301404f),
            new Rectangle(110.38917f, 315.41702f, 2.2175293f, 5.5301404f),
            new Rectangle(110.38917f, 317.63852f, 4.873749f, 5.5301404f),
            new Rectangle(110.38917f, 322.5091f, 2.65625f, 5.5301404f),
            new Rectangle(110.38917f, 325.16214f, 2.2175293f, 5.5301404f),
            new Rectangle(120.76954f, 275.22003f, 3.1029358f, 5.5301404f),
            new Rectangle(120.76954f, 278.32855f, 4.4350586f, 5.5301404f),
            new Rectangle(120.76954f, 282.7692f, 4.4350586f, 5.5301404f),
            new Rectangle(120.76954f, 287.20984f, 4.4350586f, 5.5301404f),
            new Rectangle(120.76954f, 291.65048f, 4.4350586f, 5.5301404f),
            new Rectangle(120.76954f, 296.09113f, 3.1029358f, 5.5301404f),
            new Rectangle(120.76954f, 299.19965f, 4.4350586f, 5.5301404f),
            new Rectangle(120.76954f, 303.6403f, 4.873749f, 5.5301404f),
            new Rectangle(120.76954f, 308.51962f, 4.4350586f, 5.5301404f),
            new Rectangle(120.76954f, 312.96027f, 3.1029358f, 5.5301404f),
            new Rectangle(120.76954f, 316.0688f, 4.4350586f, 5.5301404f),
            new Rectangle(120.76954f, 320.50943f, 2.2175293f, 5.5301404f),
            new Rectangle(120.76954f, 322.73093f, 4.873749f, 5.5301404f),
            new Rectangle(120.76954f, 327.61026f, 4.4350586f, 5.5301404f),
            new Rectangle(120.76954f, 332.0509f, 3.1029358f, 5.5301404f),
            new Rectangle(120.76954f, 335.15942f, 2.2175293f, 5.5301404f),
            new Rectangle(131.14992f, 284.70035f, 4.4350586f, 5.5301404f),
            new Rectangle(131.14992f, 289.133f, 4.873749f, 5.5301404f),
            new Rectangle(131.14992f, 294.00436f, 4.873749f, 5.5301404f),
            new Rectangle(131.14992f, 298.87573f, 4.873749f, 5.5301404f),
            new Rectangle(131.14992f, 303.7471f, 2.65625f, 5.5301404f),
            new Rectangle(131.14992f, 306.40094f, 3.1029358f, 5.5301404f),
            new Rectangle(131.14992f, 309.5015f, 4.4350586f, 5.5301404f),
            new Rectangle(131.14992f, 313.76025f, 2.2175293f, 5.5301404f),
            new Rectangle(131.14992f, 315.98175f, 2.65625f, 5.5301404f),
            new Rectangle(131.14992f, 318.6356f, 4.4350586f, 5.5301404f),
            new Rectangle(131.14992f, 323.06824f, 2.65625f, 5.5301404f),
            new Rectangle(120.76954f, 360.60025f, 4.873749f, 5.5301404f),
            new Rectangle(120.76954f, 365.4724f, 2.2175293f, 5.5301404f),
            new Rectangle(120.76954f, 367.6939f, 2.65625f, 5.5301404f),
            new Rectangle(120.76954f, 370.34854f, 4.4350586f, 5.5301404f),
            new Rectangle(120.76954f, 374.78198f, 2.65625f, 5.5301404f),
            new Rectangle(120.76954f, 403.82193f, 5.759186f, 5.5301404f),
            new Rectangle(120.76954f, 409.3402f, 4.4350586f, 5.5301404f),
            new Rectangle(120.76954f, 413.77365f, 4.4350586f, 5.5301404f),
            new Rectangle(120.76954f, 418.2071f, 4.873749f, 5.5301404f),
            new Rectangle(120.76954f, 423.07925f, 3.1029358f, 5.5301404f),
            new Rectangle(120.76954f, 426.1806f, 4.4350586f, 5.5301404f),
            new Rectangle(120.76954f, 430.61404f, 4.4350586f, 5.5301404f),
            new Rectangle(120.76954f, 435.0475f, 4.4350586f, 5.5301404f),
            new Rectangle(120.76954f, 439.30624f, 2.2175293f, 5.5301404f),
            new Rectangle(120.76954f, 441.52774f, 4.873749f, 5.5301404f),
            new Rectangle(120.76954f, 446.3999f, 4.4350586f, 5.5301404f),
            new Rectangle(120.76954f, 450.83334f, 4.4350586f, 5.5301404f),
            new Rectangle(120.76954f, 455.0921f, 4.4350586f, 5.5301404f),
            new Rectangle(120.76954f, 459.53113f, 2.2175293f, 5.5301404f),
            new Rectangle(148.37137f, 132.9f, 5.5688934f, 6.6683106f),
            new Rectangle(148.37137f, 138.4699f, 5.5688934f, 6.6683106f),
            new Rectangle(148.37137f, 144.0398f, 2.7844543f, 6.6683106f),
            new Rectangle(148.37137f, 146.82524f, 5.0079956f, 6.6683106f),
            new Rectangle(148.37137f, 151.83424f, 2.2235565f, 6.6683106f),
            new Rectangle(148.37137f, 154.05879f, 5.5688934f, 6.6683106f),
            new Rectangle(148.37137f, 238.71704f, 5.5688934f, 6.6683106f),
            new Rectangle(148.37137f, 292.7153f, 5.5689087f, 6.6683106f),
            new Rectangle(148.37137f, 298.2852f, 2.7844543f, 6.6683106f),
            new Rectangle(148.37137f, 301.07065f, 5.5689087f, 6.6683106f),
            new Rectangle(148.37137f, 306.64053f, 5.5689087f, 6.6683106f),
            new Rectangle(148.37137f, 312.21042f, 5.5689087f, 6.6683106f),
            new Rectangle(148.37137f, 350.90823f, 5.5689087f, 6.6683106f),
            new Rectangle(148.37137f, 356.47812f, 2.7844543f, 6.6683106f),
            new Rectangle(148.37137f, 359.26358f, 5.5689087f, 6.6683106f),
            new Rectangle(148.37137f, 364.83347f, 5.5689087f, 6.6683106f),
            new Rectangle(148.37137f, 370.40335f, 5.5689087f, 6.6683106f),
            new Rectangle(148.37137f, 375.97324f, 5.5689087f, 6.6683106f),
            new Rectangle(148.37137f, 381.54312f, 5.5689087f, 6.6683106f),
            new Rectangle(160.85129f, 132.9f, 8.343323f, 6.6683106f),
            new Rectangle(160.85129f, 141.24632f, 5.5688934f, 6.6683106f),
            new Rectangle(160.85129f, 146.81822f, 2.2235565f, 6.6683106f),
            new Rectangle(160.85129f, 149.04478f, 2.7844543f, 6.6683106f),
            new Rectangle(160.85129f, 151.83224f, 5.5688934f, 6.6683106f),
            new Rectangle(160.85129f, 235.89052f, 5.5688934f, 6.6683106f),
            new Rectangle(160.85129f, 241.46942f, 5.5688934f, 6.6683106f),
            new Rectangle(160.85129f, 296.908f, 5.5689087f, 6.6683106f),
            new Rectangle(160.85129f, 302.4799f, 5.5689087f, 6.6683106f),
            new Rectangle(160.85129f, 308.0518f, 5.5689087f, 6.6683106f),
            new Rectangle(160.85129f, 350.89023f, 5.5689087f, 6.6683106f),
            new Rectangle(160.85129f, 356.46213f, 2.7844543f, 6.6683106f),
            new Rectangle(160.85129f, 359.24957f, 5.5689087f, 6.6683106f),
            new Rectangle(160.85129f, 364.82147f, 5.5689087f, 6.6683106f),
            new Rectangle(160.85129f, 370.39337f, 5.5689087f, 6.6683106f),
            new Rectangle(160.85129f, 375.96527f, 5.5689087f, 6.6683106f),
            new Rectangle(160.85129f, 381.53717f, 5.5689087f, 6.6683106f),
            new Rectangle(173.3312f, 132.9f, 2.7844543f, 6.6683106f),
            new Rectangle(173.3312f, 135.69044f, 5.0079956f, 6.6683106f),
            new Rectangle(173.3312f, 140.70445f, 5.5688934f, 6.6683106f),
            new Rectangle(173.3312f, 146.27936f, 2.2235565f, 6.6683106f),
            new Rectangle(173.3312f, 148.50893f, 5.5688934f, 6.6683106f),
            new Rectangle(173.3312f, 154.08383f, 5.5688934f, 6.6683106f),
            new Rectangle(173.3312f, 159.65874f, 5.5688934f, 6.6683106f),
            new Rectangle(173.3312f, 235.85646f, 5.5688934f, 6.6683106f),
            new Rectangle(173.3312f, 241.43137f, 5.5688934f, 6.6683106f),
            new Rectangle(173.3312f, 292.66922f, 5.5689087f, 6.6683106f),
            new Rectangle(173.3312f, 298.24414f, 2.7844543f, 6.6683106f),
            new Rectangle(173.3312f, 301.0346f, 5.5689087f, 6.6683106f),
            new Rectangle(173.3312f, 306.60953f, 5.5689087f, 6.6683106f),
            new Rectangle(173.3312f, 312.18445f, 5.5689087f, 6.6683106f),
            new Rectangle(173.3312f, 350.88226f, 5.5689087f, 6.6683106f),
            new Rectangle(173.3312f, 356.45718f, 2.7844543f, 6.6683106f),
            new Rectangle(173.3312f, 359.24765f, 5.5689087f, 6.6683106f),
            new Rectangle(173.3312f, 364.82257f, 5.5689087f, 6.6683106f),
            new Rectangle(173.3312f, 370.3975f, 5.5689087f, 6.6683106f),
            new Rectangle(173.3312f, 375.9724f, 5.5689087f, 6.6683106f),
            new Rectangle(173.3312f, 381.54733f, 5.5689087f, 6.6683106f),
            new Rectangle(185.81113f, 132.9f, 5.5688934f, 6.6683106f),
            new Rectangle(185.81113f, 138.47389f, 5.5688934f, 6.6683106f),
            new Rectangle(185.81113f, 144.04779f, 5.0079956f, 6.6683106f),
            new Rectangle(185.81113f, 149.06079f, 5.5688934f, 6.6683106f),
            new Rectangle(185.81113f, 154.63469f, 8.343323f, 6.6683106f),
            new Rectangle(185.81113f, 162.98303f, 5.5688934f, 6.6683106f),
            new Rectangle(185.81113f, 168.55693f, 5.5688934f, 6.6683106f),
            new Rectangle(185.81113f, 174.13083f, 5.5688934f, 6.6683106f),
            new Rectangle(185.81113f, 179.70473f, 3.3353271f, 6.6683106f),
            new Rectangle(185.81113f, 183.04506f, 5.5688934f, 6.6683106f),
            new Rectangle(185.81113f, 235.8434f, 5.5688934f, 6.6683106f),
            new Rectangle(185.81113f, 241.4223f, 5.5688934f, 6.6683106f),
            new Rectangle(185.81113f, 292.66016f, 5.5689087f, 6.6683106f),
            new Rectangle(185.81113f, 298.23907f, 2.7844543f, 6.6683106f),
            new Rectangle(185.81113f, 301.02853f, 5.5689087f, 6.6683106f),
            new Rectangle(185.81113f, 306.60245f, 5.5689087f, 6.6683106f),
            new Rectangle(185.81113f, 312.17636f, 5.5689087f, 6.6683106f),
            new Rectangle(185.81113f, 350.87418f, 5.5689087f, 6.6683106f),
            new Rectangle(185.81113f, 356.4481f, 2.7844543f, 6.6683106f),
            new Rectangle(185.81113f, 359.23755f, 5.5689087f, 6.6683106f),
            new Rectangle(185.81113f, 364.81146f, 5.5689087f, 6.6683106f),
            new Rectangle(185.81113f, 370.38538f, 5.5689087f, 6.6683106f),
            new Rectangle(185.81113f, 375.9593f, 5.5689087f, 6.6683106f),
            new Rectangle(185.81113f, 381.5332f, 5.5689087f, 6.6683106f),
            new Rectangle(198.05154f, 132.9f, 2.7844543f, 6.6683106f),
            new Rectangle(198.05154f, 135.69145f, 5.0079956f, 6.6683106f),
            new Rectangle(198.05154f, 140.70647f, 3.3353271f, 6.6683106f),
            new Rectangle(198.05154f, 144.04881f, 5.5688934f, 6.6683106f),
            new Rectangle(198.05154f, 149.62473f, 5.5688934f, 6.6683106f),
            new Rectangle(198.05154f, 155.20064f, 2.2235565f, 6.6683106f),
            new Rectangle(198.05154f, 235.83844f, 5.5688934f, 6.6683106f),
            new Rectangle(198.05154f, 241.41435f, 5.5688934f, 6.6683106f),
            new Rectangle(198.05154f, 289.8928f, 5.5689087f, 6.6683106f),
            new Rectangle(198.05154f, 295.4687f, 5.5689087f, 6.6683106f),
            new Rectangle(198.05154f, 301.0446f, 2.7844543f, 6.6683106f),
            new Rectangle(198.05154f, 303.83606f, 5.5689087f, 6.6683106f),
            new Rectangle(198.05154f, 309.41196f, 5.5689087f, 6.6683106f),
            new Rectangle(198.05154f, 314.98785f, 5.5689087f, 6.6683106f),
            new Rectangle(198.05154f, 350.86615f, 5.5689087f, 6.6683106f),
            new Rectangle(198.05154f, 356.44205f, 2.7844543f, 6.6683106f),
            new Rectangle(198.05154f, 359.23352f, 5.5689087f, 6.6683106f),
            new Rectangle(198.05154f, 364.80942f, 5.5689087f, 6.6683106f),
            new Rectangle(198.05154f, 370.3853f, 5.5689087f, 6.6683106f),
            new Rectangle(198.05154f, 375.9612f, 5.5689087f, 6.6683106f),
            new Rectangle(198.05154f, 381.5371f, 5.5689087f, 6.6683106f),
            new Rectangle(211.49136f, 132.9f, 7.231552f, 6.6683106f),
            new Rectangle(211.49136f, 140.13855f, 5.0079956f, 6.6683106f),
            new Rectangle(211.49136f, 145.15356f, 5.5688934f, 6.6683106f),
            new Rectangle(211.49136f, 150.72948f, 3.3353271f, 6.6683106f),
            new Rectangle(211.49136f, 154.07182f, 5.5688934f, 6.6683106f),
            new Rectangle(211.49136f, 159.64774f, 5.0079956f, 6.6683106f),
            new Rectangle(211.49136f, 235.84846f, 5.5688934f, 6.6683106f),
            new Rectangle(211.49136f, 241.42438f, 5.5688934f, 6.6683106f),
            new Rectangle(211.49136f, 292.66324f, 5.5689087f, 6.6683106f),
            new Rectangle(211.49136f, 298.23914f, 2.7844543f, 6.6683106f),
            new Rectangle(211.49136f, 301.0306f, 5.5689087f, 6.6683106f),
            new Rectangle(211.49136f, 306.6065f, 5.5689087f, 6.6683106f),
            new Rectangle(211.49136f, 312.1824f, 5.5689087f, 6.6683106f),
            new Rectangle(211.49136f, 350.88123f, 5.5689087f, 6.6683106f),
            new Rectangle(211.49136f, 356.45712f, 2.7844543f, 6.6683106f),
            new Rectangle(211.49136f, 359.2486f, 5.5689087f, 6.6683106f),
            new Rectangle(211.49136f, 364.8245f, 5.5689087f, 6.6683106f),
            new Rectangle(211.49136f, 370.4004f, 5.5689087f, 6.6683106f),
            new Rectangle(211.49136f, 375.9763f, 5.5689087f, 6.6683106f),
            new Rectangle(211.49136f, 381.5522f, 5.5689087f, 6.6683106f),
            new Rectangle(223.97128f, 132.9f, 6.6806793f, 6.6683106f),
            new Rectangle(223.97128f, 139.58366f, 5.0079956f, 6.6683106f),
            new Rectangle(223.97128f, 144.59467f, 2.7844543f, 6.6683106f),
            new Rectangle(223.97128f, 147.38213f, 5.5688934f, 6.6683106f),
            new Rectangle(223.97128f, 152.95403f, 5.5688934f, 6.6683106f),
            new Rectangle(223.97128f, 158.52592f, 2.2235565f, 6.6683106f),
            new Rectangle(223.97128f, 160.75249f, 5.5688934f, 6.6683106f),
            new Rectangle(223.97128f, 235.87048f, 5.5688934f, 6.6683106f),
            new Rectangle(223.97128f, 241.44939f, 5.5688934f, 6.6683106f),
            new Rectangle(223.97128f, 292.68723f, 5.5689087f, 6.6683106f),
            new Rectangle(223.97128f, 298.26614f, 2.7844543f, 6.6683106f),
            new Rectangle(223.97128f, 301.0536f, 5.5689087f, 6.6683106f),
            new Rectangle(223.97128f, 306.6255f, 5.5689087f, 6.6683106f),
            new Rectangle(223.97128f, 312.1974f, 5.5689087f, 6.6683106f),
            new Rectangle(223.97128f, 350.8952f, 5.5689087f, 6.6683106f),
            new Rectangle(223.97128f, 356.4671f, 2.7844543f, 6.6683106f),
            new Rectangle(223.97128f, 359.25455f, 5.5689087f, 6.6683106f),
            new Rectangle(223.97128f, 364.82645f, 5.5689087f, 6.6683106f),
            new Rectangle(223.97128f, 370.39835f, 5.5689087f, 6.6683106f),
            new Rectangle(223.97128f, 375.97025f, 5.5689087f, 6.6683106f),
            new Rectangle(223.97128f, 381.54214f, 5.5689087f, 6.6683106f),
            new Rectangle(236.4512f, 132.9f, 6.6806793f, 6.6683106f),
            new Rectangle(236.4512f, 139.58366f, 5.5688934f, 6.6683106f),
            new Rectangle(236.4512f, 145.15556f, 2.2235565f, 6.6683106f),
            new Rectangle(236.4512f, 147.38213f, 5.5688934f, 6.6683106f),
            new Rectangle(236.4512f, 152.95403f, 5.5688934f, 6.6683106f),
            new Rectangle(236.4512f, 158.52592f, 3.3353271f, 6.6683106f),
            new Rectangle(236.4512f, 161.86426f, 2.2235565f, 6.6683106f),
            new Rectangle(236.4512f, 164.09082f, 5.5688934f, 6.6683106f),
            new Rectangle(236.4512f, 235.84845f, 5.5688934f, 6.6683106f),
            new Rectangle(236.4512f, 241.42035f, 5.5688934f, 6.6683106f),
            new Rectangle(236.4512f, 289.8978f, 5.5689087f, 6.6683106f),
            new Rectangle(236.4512f, 295.4697f, 5.5689087f, 6.6683106f),
            new Rectangle(236.4512f, 301.0416f, 2.7844543f, 6.6683106f),
            new Rectangle(236.4512f, 303.82904f, 5.5689087f, 6.6683106f),
            new Rectangle(236.4512f, 309.40094f, 5.5689087f, 6.6683106f),
            new Rectangle(236.4512f, 314.97284f, 5.5689087f, 6.6683106f),
            new Rectangle(236.4512f, 350.85016f, 5.5689087f, 6.6683106f),
            new Rectangle(236.4512f, 356.42206f, 2.7844543f, 6.6683106f),
            new Rectangle(236.4512f, 359.2095f, 5.5689087f, 6.6683106f),
            new Rectangle(236.4512f, 364.7814f, 5.5689087f, 6.6683106f),
            new Rectangle(236.4512f, 370.3533f, 5.5689087f, 6.6683106f),
            new Rectangle(236.4512f, 375.9252f, 5.5689087f, 6.6683106f),
            new Rectangle(236.4512f, 381.4971f, 5.5689087f, 6.6683106f),
            new Rectangle(248.93112f, 132.9f, 6.6806793f, 6.6683106f),
            new Rectangle(248.93112f, 139.58267f, 2.2235565f, 6.6683106f),
            new Rectangle(248.93112f, 141.80823f, 5.5688934f, 6.6683106f),
            new Rectangle(248.93112f, 147.37912f, 5.0079956f, 6.6683106f),
            new Rectangle(248.93112f, 152.38913f, 5.5688934f, 6.6683106f),
            new Rectangle(248.93112f, 157.96002f, 5.5688934f, 6.6683106f),
            new Rectangle(248.93112f, 163.53091f, 2.2235565f, 6.6683106f),
            new Rectangle(248.93112f, 165.75647f, 5.5688934f, 6.6683106f),
            new Rectangle(248.93112f, 235.8945f, 5.5688934f, 6.6683106f),
            new Rectangle(248.93112f, 241.4734f, 5.5688934f, 6.6683106f),
            new Rectangle(248.93112f, 289.95184f, 5.5689087f, 6.6683106f),
            new Rectangle(248.93112f, 295.52274f, 5.5689087f, 6.6683106f),
            new Rectangle(248.93112f, 301.09363f, 2.7844543f, 6.6683106f),
            new Rectangle(248.93112f, 303.88007f, 5.5689087f, 6.6683106f),
            new Rectangle(248.93112f, 309.45096f, 5.5689087f, 6.6683106f),
            new Rectangle(248.93112f, 315.02185f, 5.5689087f, 6.6683106f),
            new Rectangle(248.93112f, 350.90015f, 5.5689087f, 6.6683106f),
            new Rectangle(248.93112f, 356.47104f, 2.7844543f, 6.6683106f),
            new Rectangle(248.93112f, 359.25748f, 5.5689087f, 6.6683106f),
            new Rectangle(248.93112f, 364.82837f, 5.5689087f, 6.6683106f),
            new Rectangle(248.93112f, 370.39926f, 5.5689087f, 6.6683106f),
            new Rectangle(248.93112f, 375.97015f, 5.5689087f, 6.6683106f),
            new Rectangle(248.93112f, 381.54105f, 5.5689087f, 6.6683106f),
            new Rectangle(261.41104f, 132.9f, 6.6806793f, 6.6683106f),
            new Rectangle(261.41104f, 139.58667f, 7.231552f, 6.6683106f),
            new Rectangle(261.41104f, 146.82423f, 2.2235565f, 6.6683106f),
            new Rectangle(261.41104f, 149.0538f, 2.7844543f, 6.6683106f),
            new Rectangle(261.41104f, 151.84425f, 5.0079956f, 6.6683106f),
            new Rectangle(261.41104f, 156.85826f, 5.5688934f, 6.6683106f),
            new Rectangle(261.41104f, 162.43317f, 3.3353271f, 6.6683106f),
            new Rectangle(261.41104f, 165.7745f, 2.2235565f, 6.6683106f),
            new Rectangle(261.41104f, 168.00407f, 5.5688934f, 6.6683106f),
            new Rectangle(261.41104f, 173.57898f, 5.5688934f, 6.6683106f),
            new Rectangle(261.41104f, 179.15388f, 5.5688934f, 6.6683106f),
            new Rectangle(261.41104f, 235.85246f, 5.5688934f, 6.6683106f),
            new Rectangle(261.41104f, 241.42737f, 5.5688934f, 6.6683106f),
            new Rectangle(261.41104f, 289.90582f, 5.5689087f, 6.6683106f),
            new Rectangle(261.41104f, 295.48074f, 5.5689087f, 6.6683106f),
            new Rectangle(261.41104f, 301.05566f, 2.7844543f, 6.6683106f),
            new Rectangle(261.41104f, 303.84613f, 5.5689087f, 6.6683106f),
            new Rectangle(261.41104f, 309.42105f, 5.5689087f, 6.6683106f),
            new Rectangle(261.41104f, 314.99597f, 5.5689087f, 6.6683106f),
            new Rectangle(261.41104f, 350.8743f, 5.5689087f, 6.6683106f),
            new Rectangle(261.41104f, 356.44922f, 2.7844543f, 6.6683106f),
            new Rectangle(261.41104f, 359.2397f, 5.5689087f, 6.6683106f),
            new Rectangle(261.41104f, 364.8146f, 5.5689087f, 6.6683106f),
            new Rectangle(261.41104f, 370.38953f, 5.5689087f, 6.6683106f),
            new Rectangle(261.41104f, 375.96445f, 5.5689087f, 6.6683106f),
            new Rectangle(261.41104f, 381.53937f, 5.5689087f, 6.6683106f),
            new Rectangle(273.89096f, 132.9f, 6.6806793f, 6.6683106f),
            new Rectangle(273.89096f, 139.58467f, 5.5688934f, 6.6683106f),
            new Rectangle(273.89096f, 145.15758f, 5.0079956f, 6.6683106f),
            new Rectangle(273.89096f, 150.16959f, 2.7844543f, 6.6683106f),
            new Rectangle(273.89096f, 152.95804f, 3.3353271f, 6.6683106f),
            new Rectangle(273.89096f, 156.29738f, 2.2235565f, 6.6683106f),
            new Rectangle(273.89096f, 158.52493f, 5.5688934f, 6.6683106f),
            new Rectangle(273.89096f, 235.86348f, 5.5688934f, 6.6683106f),
            new Rectangle(273.89096f, 241.4424f, 5.5688934f, 6.6683106f),
            new Rectangle(273.89096f, 289.92084f, 5.5689087f, 6.6683106f),
            new Rectangle(273.89096f, 295.49374f, 5.5689087f, 6.6683106f),
            new Rectangle(273.89096f, 301.06665f, 2.7844543f, 6.6683106f),
            new Rectangle(273.89096f, 303.8551f, 5.5689087f, 6.6683106f),
            new Rectangle(273.89096f, 309.428f, 5.5689087f, 6.6683106f),
            new Rectangle(273.89096f, 315.00092f, 5.5689087f, 6.6683106f),
            new Rectangle(273.89096f, 350.87924f, 5.5689087f, 6.6683106f),
            new Rectangle(273.89096f, 356.45215f, 2.7844543f, 6.6683106f),
            new Rectangle(273.89096f, 359.2406f, 5.5689087f, 6.6683106f),
            new Rectangle(273.89096f, 364.8135f, 5.5689087f, 6.6683106f),
            new Rectangle(273.89096f, 370.3864f, 5.5689087f, 6.6683106f),
            new Rectangle(273.89096f, 375.95932f, 5.5689087f, 6.6683106f),
            new Rectangle(273.89096f, 381.53223f, 5.5689087f, 6.6683106f),
            new Rectangle(286.37088f, 132.9f, 7.231552f, 6.6683106f),
            new Rectangle(286.37088f, 140.14056f, 5.0079956f, 6.6683106f),
            new Rectangle(286.37088f, 145.15758f, 5.5688934f, 6.6683106f),
            new Rectangle(286.37088f, 150.73549f, 5.0079956f, 6.6683106f),
            new Rectangle(286.37088f, 155.7525f, 5.5688934f, 6.6683106f),
            new Rectangle(286.37088f, 161.33041f, 2.7844543f, 6.6683106f),
            new Rectangle(286.37088f, 164.09183f, 7.231552f, 6.6683106f),
            new Rectangle(286.37088f, 171.3324f, 5.5688934f, 6.6683106f),
            new Rectangle(286.37088f, 176.91031f, 5.5688934f, 6.6683106f),
            new Rectangle(286.37088f, 182.48822f, 5.5688934f, 6.6683106f),
            new Rectangle(286.37088f, 188.06613f, 5.5688934f, 6.6683106f),
            new Rectangle(286.37088f, 193.64404f, 2.2235565f, 6.6683106f),
            new Rectangle(286.37088f, 195.8766f, 2.2235565f, 6.6683106f),
            new Rectangle(286.37088f, 198.10916f, 5.0079956f, 6.6683106f),
            new Rectangle(286.37088f, 235.78935f, 5.5688934f, 6.6683106f),
            new Rectangle(286.37088f, 241.36726f, 5.5688934f, 6.6683106f),
            new Rectangle(286.37088f, 289.8457f, 5.5689087f, 6.6683106f),
            new Rectangle(286.37088f, 295.4236f, 5.5689087f, 6.6683106f),
            new Rectangle(286.37088f, 301.00153f, 2.7844543f, 6.6683106f),
            new Rectangle(286.37088f, 303.79498f, 5.5689087f, 6.6683106f),
            new Rectangle(286.37088f, 309.3729f, 5.5689087f, 6.6683106f),
            new Rectangle(286.37088f, 314.9508f, 5.5689087f, 6.6683106f),
            new Rectangle(286.37088f, 350.82913f, 5.5689087f, 6.6683106f),
            new Rectangle(286.37088f, 356.40704f, 2.7844543f, 6.6683106f),
            new Rectangle(286.37088f, 359.2005f, 5.5689087f, 6.6683106f),
            new Rectangle(286.37088f, 364.7784f, 5.5689087f, 6.6683106f),
            new Rectangle(286.37088f, 370.35632f, 5.5689087f, 6.6683106f),
            new Rectangle(286.37088f, 375.93423f, 5.5689087f, 6.6683106f),
            new Rectangle(286.37088f, 381.51215f, 5.5689087f, 6.6683106f),
            new Rectangle(298.6113f, 132.9f, 5.5688934f, 6.6683106f),
            new Rectangle(298.6113f, 138.4729f, 2.2235565f, 6.6683106f),
            new Rectangle(298.6113f, 140.70045f, 2.7844543f, 6.6683106f),
            new Rectangle(298.6113f, 143.4889f, 5.5688934f, 6.6683106f),
            new Rectangle(298.6113f, 149.06181f, 5.5688934f, 6.6683106f),
            new Rectangle(298.6113f, 154.63472f, 5.5688934f, 6.6683106f),
            new Rectangle(298.6113f, 160.20763f, 5.5688934f, 6.6683106f),
            new Rectangle(298.6113f, 165.78053f, 2.2235565f, 6.6683106f),
            new Rectangle(298.6113f, 168.00809f, 5.5688934f, 6.6683106f),
            new Rectangle(298.6113f, 235.86649f, 5.5688934f, 6.6683106f),
            new Rectangle(298.6113f, 241.4454f, 5.5688934f, 6.6683106f),
            new Rectangle(298.6113f, 289.92386f, 5.5689087f, 6.6683106f),
            new Rectangle(298.6113f, 295.49677f, 5.5689087f, 6.6683106f),
            new Rectangle(298.6113f, 301.06967f, 2.7844543f, 6.6683106f),
            new Rectangle(298.6113f, 303.85812f, 5.5689087f, 6.6683106f),
            new Rectangle(298.6113f, 309.43103f, 5.5689087f, 6.6683106f),
            new Rectangle(298.6113f, 315.00394f, 5.5689087f, 6.6683106f),
            new Rectangle(298.6113f, 350.88226f, 5.5689087f, 6.6683106f),
            new Rectangle(298.6113f, 356.45517f, 2.7844543f, 6.6683106f),
            new Rectangle(298.6113f, 359.24362f, 5.5689087f, 6.6683106f),
            new Rectangle(298.6113f, 364.81653f, 5.5689087f, 6.6683106f),
            new Rectangle(298.6113f, 370.38943f, 5.5689087f, 6.6683106f),
            new Rectangle(298.6113f, 375.96234f, 5.5689087f, 6.6683106f),
            new Rectangle(298.6113f, 381.53525f, 5.5689087f, 6.6683106f),
            new Rectangle(312.05112f, 132.9f, 6.1197815f, 6.6683106f),
            new Rectangle(312.05112f, 139.02779f, 5.5688934f, 6.6683106f),
            new Rectangle(312.05112f, 144.60469f, 3.3353271f, 6.6683106f),
            new Rectangle(312.05112f, 147.94803f, 5.0079956f, 6.6683106f),
            new Rectangle(312.05112f, 152.96404f, 5.5688934f, 6.6683106f),
            new Rectangle(312.05112f, 158.54094f, 5.0079956f, 6.6683106f),
            new Rectangle(312.05112f, 235.82037f, 5.5688934f, 6.6683106f),
            new Rectangle(312.05112f, 241.39728f, 5.5688934f, 6.6683106f),
            new Rectangle(312.05112f, 289.8757f, 5.5689087f, 6.6683106f),
            new Rectangle(312.05112f, 295.4526f, 5.5689087f, 6.6683106f),
            new Rectangle(312.05112f, 301.0295f, 2.7844543f, 6.6683106f),
            new Rectangle(312.05112f, 303.82196f, 5.5689087f, 6.6683106f),
            new Rectangle(312.05112f, 309.39886f, 5.5689087f, 6.6683106f),
            new Rectangle(312.05112f, 314.97577f, 5.5689087f, 6.6683106f),
            new Rectangle(312.05112f, 350.85406f, 5.5689087f, 6.6683106f),
            new Rectangle(312.05112f, 356.43097f, 2.7844543f, 6.6683106f),
            new Rectangle(312.05112f, 359.22342f, 5.5689087f, 6.6683106f),
            new Rectangle(312.05112f, 364.80032f, 5.5689087f, 6.6683106f),
            new Rectangle(312.05112f, 370.37723f, 5.5689087f, 6.6683106f),
            new Rectangle(312.05112f, 375.95413f, 5.5689087f, 6.6683106f),
            new Rectangle(312.05112f, 381.53104f, 5.5689087f, 6.6683106f),
            new Rectangle(324.53104f, 132.9f, 7.231552f, 6.6683106f),
            new Rectangle(324.53104f, 140.13855f, 5.5688934f, 6.6683106f),
            new Rectangle(324.53104f, 145.71446f, 2.7844543f, 6.6683106f),
            new Rectangle(324.53104f, 148.50592f, 5.5688934f, 6.6683106f),
            new Rectangle(324.53104f, 154.08183f, 5.5688934f, 6.6683106f),
            new Rectangle(324.53104f, 159.65775f, 3.3353271f, 6.6683106f),
            new Rectangle(324.53104f, 163.00009f, 2.2235565f, 6.6683106f),
            new Rectangle(324.53104f, 165.23065f, 5.5688934f, 6.6683106f),
            new Rectangle(324.53104f, 170.80656f, 5.5688934f, 6.6683106f),
            new Rectangle(324.53104f, 176.38248f, 5.5688934f, 6.6683106f),
            new Rectangle(324.53104f, 181.95839f, 5.0079956f, 6.6683106f),
            new Rectangle(324.53104f, 233.07806f, 5.5688934f, 6.6683106f),
            new Rectangle(324.53104f, 238.65398f, 5.5688934f, 6.6683106f),
            new Rectangle(324.53104f, 244.22989f, 5.5688934f, 6.6683106f),
            new Rectangle(324.53104f, 287.06833f, 5.5689087f, 6.6683106f),
            new Rectangle(324.53104f, 292.64423f, 5.5689087f, 6.6683106f),
            new Rectangle(324.53104f, 298.22012f, 5.5689087f, 6.6683106f),
            new Rectangle(324.53104f, 303.79602f, 2.7844543f, 6.6683106f),
            new Rectangle(324.53104f, 306.5875f, 5.5689087f, 6.6683106f),
            new Rectangle(324.53104f, 312.1634f, 5.5689087f, 6.6683106f),
            new Rectangle(324.53104f, 317.7393f, 5.5689087f, 6.6683106f),
            new Rectangle(324.53104f, 350.85718f, 5.5689087f, 6.6683106f),
            new Rectangle(324.53104f, 356.43307f, 2.7844543f, 6.6683106f),
            new Rectangle(324.53104f, 359.22455f, 5.5689087f, 6.6683106f),
            new Rectangle(324.53104f, 364.80045f, 5.5689087f, 6.6683106f),
            new Rectangle(324.53104f, 370.37634f, 5.5689087f, 6.6683106f),
            new Rectangle(324.53104f, 375.95224f, 5.5689087f, 6.6683106f),
            new Rectangle(324.53104f, 381.52814f, 5.5689087f, 6.6683106f),
            new Rectangle(337.01096f, 132.9f, 7.231552f, 6.6683106f),
            new Rectangle(337.01096f, 140.13855f, 5.5688934f, 6.6683106f),
            new Rectangle(337.01096f, 145.71446f, 8.343323f, 6.6683106f),
            new Rectangle(337.01096f, 154.0648f, 5.5688934f, 6.6683106f),
            new Rectangle(337.01096f, 159.64072f, 5.5688934f, 6.6683106f),
            new Rectangle(337.01096f, 165.21663f, 2.2235565f, 6.6683106f),
            new Rectangle(337.01096f, 167.44719f, 5.5688934f, 6.6683106f),
            new Rectangle(337.01096f, 233.08505f, 5.5688934f, 6.6683106f),
            new Rectangle(337.01096f, 238.66096f, 5.5688934f, 6.6683106f),
            new Rectangle(337.01096f, 244.23688f, 5.5688934f, 6.6683106f),
            new Rectangle(337.01096f, 289.8948f, 5.5689087f, 6.6683106f),
            new Rectangle(337.01096f, 295.4707f, 5.5689087f, 6.6683106f),
            new Rectangle(337.01096f, 301.0466f, 2.7844543f, 6.6683106f),
            new Rectangle(337.01096f, 303.83807f, 5.5689087f, 6.6683106f),
            new Rectangle(337.01096f, 309.41397f, 5.5689087f, 6.6683106f),
            new Rectangle(337.01096f, 314.98987f, 5.5689087f, 6.6683106f),
            new Rectangle(337.01096f, 350.86816f, 5.5689087f, 6.6683106f),
            new Rectangle(337.01096f, 356.44406f, 2.7844543f, 6.6683106f),
            new Rectangle(337.01096f, 359.23553f, 5.5689087f, 6.6683106f),
            new Rectangle(337.01096f, 364.81143f, 5.5689087f, 6.6683106f),
            new Rectangle(337.01096f, 370.38733f, 5.5689087f, 6.6683106f),
            new Rectangle(337.01096f, 375.96323f, 5.5689087f, 6.6683106f),
            new Rectangle(337.01096f, 381.53912f, 5.5689087f, 6.6683106f),
            new Rectangle(349.49088f, 132.9f, 7.79245f, 6.6683106f),
            new Rectangle(349.49088f, 140.70146f, 3.3353271f, 6.6683106f),
            new Rectangle(349.49088f, 144.0458f, 5.5688934f, 6.6683106f),
            new Rectangle(349.49088f, 149.62372f, 5.5688934f, 6.6683106f),
            new Rectangle(349.49088f, 155.20163f, 5.0079956f, 6.6683106f),
            new Rectangle(349.49088f, 160.21864f, 5.5688934f, 6.6683106f),
            new Rectangle(349.49088f, 233.05699f, 5.5688934f, 6.6683106f),
            new Rectangle(349.49088f, 238.6349f, 5.5688934f, 6.6683106f),
            new Rectangle(349.49088f, 244.21281f, 5.5688934f, 6.6683106f),
            new Rectangle(349.49088f, 289.87076f, 5.5689087f, 6.6683106f),
            new Rectangle(349.49088f, 295.44867f, 5.5689087f, 6.6683106f),
            new Rectangle(349.49088f, 301.02658f, 2.7844543f, 6.6683106f),
            new Rectangle(349.49088f, 303.82004f, 5.5689087f, 6.6683106f),
            new Rectangle(349.49088f, 309.39795f, 5.5689087f, 6.6683106f),
            new Rectangle(349.49088f, 314.97586f, 5.5689087f, 6.6683106f),
            new Rectangle(349.49088f, 350.8542f, 5.5689087f, 6.6683106f),
            new Rectangle(349.49088f, 356.4321f, 2.7844543f, 6.6683106f),
            new Rectangle(349.49088f, 359.22556f, 5.5689087f, 6.6683106f),
            new Rectangle(349.49088f, 364.80347f, 5.5689087f, 6.6683106f),
            new Rectangle(349.49088f, 370.38138f, 5.5689087f, 6.6683106f),
            new Rectangle(349.49088f, 375.9593f, 5.5689087f, 6.6683106f),
            new Rectangle(349.49088f, 381.5372f, 5.5689087f, 6.6683106f),
            new Rectangle(361.9708f, 132.9f, 6.6806793f, 6.6683106f),
            new Rectangle(361.9708f, 139.58568f, 5.5688934f, 6.6683106f),
            new Rectangle(361.9708f, 145.15958f, 2.2235565f, 6.6683106f),
            new Rectangle(361.9708f, 147.38814f, 5.5688934f, 6.6683106f),
            new Rectangle(361.9708f, 152.96204f, 5.5688934f, 6.6683106f),
            new Rectangle(361.9708f, 158.53593f, 5.5688934f, 6.6683106f),
            new Rectangle(361.9708f, 233.11406f, 5.5688934f, 6.6683106f),
            new Rectangle(361.9708f, 238.68796f, 5.5688934f, 6.6683106f),
            new Rectangle(361.9708f, 244.26186f, 5.5688934f, 6.6683106f),
            new Rectangle(361.9708f, 287.10028f, 5.5689087f, 6.6683106f),
            new Rectangle(361.9708f, 292.6742f, 5.5689087f, 6.6683106f),
            new Rectangle(361.9708f, 298.2481f, 5.5689087f, 6.6683106f),
            new Rectangle(361.9708f, 303.82202f, 2.7844543f, 6.6683106f),
            new Rectangle(361.9708f, 306.61148f, 5.5689087f, 6.6683106f),
            new Rectangle(361.9708f, 312.1854f, 5.5689087f, 6.6683106f),
            new Rectangle(361.9708f, 317.7593f, 5.5689087f, 6.6683106f),
            new Rectangle(361.9708f, 350.87723f, 5.5689087f, 6.6683106f),
            new Rectangle(361.9708f, 356.45114f, 2.7844543f, 6.6683106f),
            new Rectangle(361.9708f, 359.2406f, 5.5689087f, 6.6683106f),
            new Rectangle(361.9708f, 364.8145f, 5.5689087f, 6.6683106f),
            new Rectangle(361.9708f, 370.38843f, 5.5689087f, 6.6683106f),
            new Rectangle(361.9708f, 375.96234f, 5.5689087f, 6.6683106f),
            new Rectangle(361.9708f, 381.53625f, 5.5689087f, 6.6683106f),
            new Rectangle(374.4507f, 132.9f, 6.6806793f, 6.6683106f),
            new Rectangle(374.4507f, 139.58768f, 7.231552f, 6.6683106f),
            new Rectangle(374.4507f, 146.82623f, 5.5688934f, 6.6683106f),
            new Rectangle(374.4507f, 152.40215f, 5.5688934f, 6.6683106f),
            new Rectangle(374.4507f, 157.97806f, 5.5688934f, 6.6683106f),
            new Rectangle(374.4507f, 163.55397f, 5.5688934f, 6.6683106f),
            new Rectangle(374.4507f, 233.09206f, 5.5688934f, 6.6683106f),
            new Rectangle(374.4507f, 238.66797f, 5.5688934f, 6.6683106f),
            new Rectangle(374.4507f, 244.24388f, 5.5688934f, 6.6683106f),
            new Rectangle(374.4507f, 287.0823f, 5.5689087f, 6.6683106f),
            new Rectangle(374.4507f, 292.6582f, 5.5689087f, 6.6683106f),
            new Rectangle(374.4507f, 298.2341f, 5.5689087f, 6.6683106f),
            new Rectangle(374.4507f, 303.81f, 2.7844543f, 6.6683106f),
            new Rectangle(374.4507f, 306.60147f, 5.5689087f, 6.6683106f),
            new Rectangle(374.4507f, 312.17737f, 5.5689087f, 6.6683106f),
            new Rectangle(374.4507f, 317.75327f, 5.5689087f, 6.6683106f),
            new Rectangle(374.4507f, 350.87115f, 5.5689087f, 6.6683106f),
            new Rectangle(374.4507f, 356.44705f, 2.7844543f, 6.6683106f),
            new Rectangle(374.4507f, 359.23853f, 5.5689087f, 6.6683106f),
            new Rectangle(374.4507f, 364.81442f, 5.5689087f, 6.6683106f),
            new Rectangle(374.4507f, 370.39032f, 5.5689087f, 6.6683106f),
            new Rectangle(374.4507f, 375.96622f, 5.5689087f, 6.6683106f),
            new Rectangle(374.4507f, 381.5421f, 5.5689087f, 6.6683106f),
            new Rectangle(386.93063f, 132.9f, 7.231552f, 6.6683106f),
            new Rectangle(386.93063f, 140.13855f, 3.3353271f, 6.6683106f),
            new Rectangle(386.93063f, 143.4809f, 5.5688934f, 6.6683106f),
            new Rectangle(386.93063f, 149.05681f, 5.5688934f, 6.6683106f),
            new Rectangle(386.93063f, 154.63272f, 2.7844543f, 6.6683106f),
            new Rectangle(386.93063f, 157.42418f, 2.2235565f, 6.6683106f),
            new Rectangle(386.93063f, 159.65474f, 5.5688934f, 6.6683106f),
            new Rectangle(386.93063f, 233.09406f, 5.5688934f, 6.6683106f),
            new Rectangle(386.93063f, 238.66997f, 5.5688934f, 6.6683106f),
            new Rectangle(386.93063f, 244.24588f, 5.5688934f, 6.6683106f),
            new Rectangle(386.93063f, 289.90482f, 5.5689087f, 6.6683106f),
            new Rectangle(386.93063f, 295.4807f, 5.5689087f, 6.6683106f),
            new Rectangle(386.93063f, 301.0566f, 2.7844543f, 6.6683106f),
            new Rectangle(386.93063f, 303.84808f, 5.5689087f, 6.6683106f),
            new Rectangle(386.93063f, 309.42398f, 5.5689087f, 6.6683106f),
            new Rectangle(386.93063f, 314.99988f, 5.5689087f, 6.6683106f),
            new Rectangle(386.93063f, 350.87918f, 5.5689087f, 6.6683106f),
            new Rectangle(386.93063f, 356.45508f, 2.7844543f, 6.6683106f),
            new Rectangle(386.93063f, 359.24655f, 5.5689087f, 6.6683106f),
            new Rectangle(386.93063f, 364.82245f, 5.5689087f, 6.6683106f),
            new Rectangle(386.93063f, 370.39835f, 5.5689087f, 6.6683106f),
            new Rectangle(386.93063f, 375.97424f, 5.5689087f, 6.6683106f),
            new Rectangle(386.93063f, 381.55014f, 5.5689087f, 6.6683106f),
            new Rectangle(399.41055f, 132.9f, 7.231552f, 6.6683106f),
            new Rectangle(399.41055f, 140.13956f, 5.5688934f, 6.6683106f),
            new Rectangle(399.41055f, 145.71646f, 5.5688934f, 6.6683106f),
            new Rectangle(399.41055f, 151.29337f, 8.343323f, 6.6683106f),
            new Rectangle(399.41055f, 159.64471f, 5.5688934f, 6.6683106f),
            new Rectangle(399.41055f, 165.22162f, 3.3353271f, 6.6683106f),
            new Rectangle(399.41055f, 168.56496f, 5.0079956f, 6.6683106f),
            new Rectangle(399.41055f, 233.06499f, 5.5688934f, 6.6683106f),
            new Rectangle(399.41055f, 238.64189f, 5.5688934f, 6.6683106f),
            new Rectangle(399.41055f, 244.2188f, 5.5688934f, 6.6683106f),
            new Rectangle(399.41055f, 289.8767f, 5.5689087f, 6.6683106f),
            new Rectangle(399.41055f, 295.4536f, 5.5689087f, 6.6683106f),
            new Rectangle(399.41055f, 301.03052f, 2.7844543f, 6.6683106f),
            new Rectangle(399.41055f, 303.82297f, 5.5689087f, 6.6683106f),
            new Rectangle(399.41055f, 309.39987f, 5.5689087f, 6.6683106f),
            new Rectangle(399.41055f, 314.97678f, 5.5689087f, 6.6683106f),
            new Rectangle(399.41055f, 350.85507f, 5.5689087f, 6.6683106f),
            new Rectangle(399.41055f, 356.43198f, 2.7844543f, 6.6683106f),
            new Rectangle(399.41055f, 359.22443f, 5.5689087f, 6.6683106f),
            new Rectangle(399.41055f, 364.80133f, 5.5689087f, 6.6683106f),
            new Rectangle(399.41055f, 370.37823f, 5.5689087f, 6.6683106f),
            new Rectangle(399.41055f, 375.95514f, 5.5689087f, 6.6683106f),
            new Rectangle(399.41055f, 381.53204f, 5.5689087f, 6.6683106f),
            new Rectangle(411.89047f, 132.9f, 6.6806793f, 6.6683106f),
            new Rectangle(411.89047f, 139.58467f, 5.5688934f, 6.6683106f),
            new Rectangle(411.89047f, 145.15758f, 2.2235565f, 6.6683106f),
            new Rectangle(411.89047f, 147.38513f, 5.5688934f, 6.6683106f),
            new Rectangle(411.89047f, 152.95804f, 2.2235565f, 6.6683106f),
            new Rectangle(411.89047f, 155.1856f, 5.5688934f, 6.6683106f),
            new Rectangle(411.89047f, 160.7585f, 8.343323f, 6.6683106f),
            new Rectangle(411.89047f, 233.11809f, 5.5688934f, 6.6683106f),
            new Rectangle(411.89047f, 238.691f, 5.5688934f, 6.6683106f),
            new Rectangle(411.89047f, 244.2639f, 5.5688934f, 6.6683106f),
            new Rectangle(411.89047f, 289.92184f, 5.5689087f, 6.6683106f),
            new Rectangle(411.89047f, 295.49475f, 5.5689087f, 6.6683106f),
            new Rectangle(411.89047f, 301.06766f, 2.7844543f, 6.6683106f),
            new Rectangle(411.89047f, 303.8561f, 5.5689087f, 6.6683106f),
            new Rectangle(411.89047f, 309.42902f, 5.5689087f, 6.6683106f),
            new Rectangle(411.89047f, 315.00192f, 5.5689087f, 6.6683106f),
            new Rectangle(411.89047f, 350.88025f, 5.5689087f, 6.6683106f),
            new Rectangle(411.89047f, 356.45316f, 2.7844543f, 6.6683106f),
            new Rectangle(411.89047f, 359.2416f, 5.5689087f, 6.6683106f),
            new Rectangle(411.89047f, 364.8145f, 5.5689087f, 6.6683106f),
            new Rectangle(411.89047f, 370.38742f, 5.5689087f, 6.6683106f),
            new Rectangle(411.89047f, 375.96033f, 5.5689087f, 6.6683106f),
            new Rectangle(411.89047f, 381.53323f, 5.5689087f, 6.6683106f),
            new Rectangle(424.3704f, 132.9f, 6.6806793f, 6.6683106f),
            new Rectangle(424.3704f, 139.58467f, 2.2235565f, 6.6683106f),
            new Rectangle(424.3704f, 141.81223f, 5.5688934f, 6.6683106f),
            new Rectangle(424.3704f, 147.38513f, 5.0079956f, 6.6683106f),
            new Rectangle(424.3704f, 152.39714f, 5.5688934f, 6.6683106f),
            new Rectangle(424.3704f, 157.97005f, 5.0079956f, 6.6683106f),
            new Rectangle(424.3704f, 162.98206f, 2.2235565f, 6.6683106f),
            new Rectangle(424.3704f, 165.20961f, 5.5688934f, 6.6683106f),
            new Rectangle(424.3704f, 233.1291f, 5.5688934f, 6.6683106f),
            new Rectangle(424.3704f, 238.70201f, 5.5688934f, 6.6683106f),
            new Rectangle(424.3704f, 244.27492f, 5.5688934f, 6.6683106f),
            new Rectangle(424.3704f, 289.93387f, 5.5689087f, 6.6683106f),
            new Rectangle(424.3704f, 295.50677f, 5.5689087f, 6.6683106f),
            new Rectangle(424.3704f, 301.07968f, 2.7844543f, 6.6683106f),
            new Rectangle(424.3704f, 303.86813f, 5.5689087f, 6.6683106f),
            new Rectangle(424.3704f, 309.44104f, 5.5689087f, 6.6683106f),
            new Rectangle(424.3704f, 315.01395f, 5.5689087f, 6.6683106f),
            new Rectangle(424.3704f, 350.89325f, 5.5689087f, 6.6683106f),
            new Rectangle(424.3704f, 356.46616f, 2.7844543f, 6.6683106f),
            new Rectangle(424.3704f, 359.2546f, 5.5689087f, 6.6683106f),
            new Rectangle(424.3704f, 364.8275f, 5.5689087f, 6.6683106f),
            new Rectangle(424.3704f, 370.40042f, 5.5689087f, 6.6683106f),
            new Rectangle(424.3704f, 375.97333f, 5.5689087f, 6.6683106f),
            new Rectangle(424.3704f, 381.54623f, 5.5689087f, 6.6683106f),
            new Rectangle(436.8503f, 132.9f, 7.231552f, 6.6683106f),
            new Rectangle(436.8503f, 140.13956f, 5.5688934f, 6.6683106f),
            new Rectangle(436.8503f, 145.71646f, 5.5688934f, 6.6683106f),
            new Rectangle(436.8503f, 151.29337f, 5.5688934f, 6.6683106f),
            new Rectangle(436.8503f, 156.87027f, 5.5688934f, 6.6683106f),
            new Rectangle(436.8503f, 162.44717f, 3.3353271f, 6.6683106f),
            new Rectangle(436.8503f, 165.79051f, 5.0079956f, 6.6683106f),
            new Rectangle(436.8503f, 233.04994f, 5.5688934f, 6.6683106f),
            new Rectangle(436.8503f, 238.62685f, 5.5688934f, 6.6683106f),
            new Rectangle(436.8503f, 244.20375f, 5.5688934f, 6.6683106f),
            new Rectangle(436.8503f, 289.8617f, 5.5689087f, 6.6683106f),
            new Rectangle(436.8503f, 295.4386f, 5.5689087f, 6.6683106f),
            new Rectangle(436.8503f, 301.0155f, 2.7844543f, 6.6683106f),
            new Rectangle(436.8503f, 303.80795f, 5.5689087f, 6.6683106f),
            new Rectangle(436.8503f, 309.38486f, 5.5689087f, 6.6683106f),
            new Rectangle(436.8503f, 314.96176f, 5.5689087f, 6.6683106f),
            new Rectangle(436.8503f, 350.84006f, 5.5689087f, 6.6683106f),
            new Rectangle(436.8503f, 356.41696f, 2.7844543f, 6.6683106f),
            new Rectangle(436.8503f, 359.2094f, 5.5689087f, 6.6683106f),
            new Rectangle(436.8503f, 364.78632f, 5.5689087f, 6.6683106f),
            new Rectangle(436.8503f, 370.36322f, 5.5689087f, 6.6683106f),
            new Rectangle(436.8503f, 375.94012f, 5.5689087f, 6.6683106f),
            new Rectangle(436.8503f, 381.51703f, 5.5689087f, 6.6683106f),
            new Rectangle(449.33023f, 132.9f, 7.231552f, 6.6683106f),
            new Rectangle(449.33023f, 140.14056f, 5.5688934f, 6.6683106f),
            new Rectangle(449.33023f, 145.71848f, 3.3353271f, 6.6683106f),
            new Rectangle(449.33023f, 149.06282f, 7.231552f, 6.6683106f),
            new Rectangle(449.33023f, 156.30339f, 5.5688934f, 6.6683106f),
            new Rectangle(449.33023f, 161.8813f, 5.0079956f, 6.6683106f),
            new Rectangle(449.33023f, 233.04099f, 5.5688934f, 6.6683106f),
            new Rectangle(449.33023f, 238.6189f, 5.5688934f, 6.6683106f),
            new Rectangle(449.33023f, 244.19681f, 5.5688934f, 6.6683106f),
            new Rectangle(449.33023f, 289.85474f, 5.5689087f, 6.6683106f),
            new Rectangle(449.33023f, 295.43265f, 5.5689087f, 6.6683106f),
            new Rectangle(449.33023f, 301.01056f, 2.7844543f, 6.6683106f),
            new Rectangle(449.33023f, 303.80402f, 5.5689087f, 6.6683106f),
            new Rectangle(449.33023f, 309.38193f, 5.5689087f, 6.6683106f),
            new Rectangle(449.33023f, 314.95984f, 5.5689087f, 6.6683106f),
            new Rectangle(449.33023f, 350.83817f, 5.5689087f, 6.6683106f),
            new Rectangle(449.33023f, 356.41608f, 2.7844543f, 6.6683106f),
            new Rectangle(449.33023f, 359.20953f, 5.5689087f, 6.6683106f),
            new Rectangle(449.33023f, 364.78745f, 5.5689087f, 6.6683106f),
            new Rectangle(449.33023f, 370.36536f, 5.5689087f, 6.6683106f),
            new Rectangle(449.33023f, 375.94327f, 5.5689087f, 6.6683106f),
            new Rectangle(449.33023f, 381.52118f, 5.5689087f, 6.6683106f),
            new Rectangle(461.81015f, 132.9f, 6.1197815f, 6.6683106f),
            new Rectangle(461.81015f, 139.02478f, 2.2235565f, 6.6683106f),
            new Rectangle(461.81015f, 141.25334f, 5.5688934f, 6.6683106f),
            new Rectangle(461.81015f, 146.82724f, 2.2235565f, 6.6683106f),
            new Rectangle(461.81015f, 149.0558f, 5.5688934f, 6.6683106f),
            new Rectangle(461.81015f, 154.6297f, 5.5688934f, 6.6683106f),
            new Rectangle(461.81015f, 160.2036f, 5.5688934f, 6.6683106f),
            new Rectangle(461.81015f, 233.10205f, 5.5688934f, 6.6683106f),
            new Rectangle(461.81015f, 238.67595f, 5.5688934f, 6.6683106f),
            new Rectangle(461.81015f, 244.24985f, 5.5688934f, 6.6683106f),
            new Rectangle(461.81015f, 289.90778f, 5.5689087f, 6.6683106f),
            new Rectangle(461.81015f, 295.4817f, 5.5689087f, 6.6683106f),
            new Rectangle(461.81015f, 301.0556f, 2.7844543f, 6.6683106f),
            new Rectangle(461.81015f, 303.84506f, 5.5689087f, 6.6683106f),
            new Rectangle(461.81015f, 309.41898f, 5.5689087f, 6.6683106f),
            new Rectangle(461.81015f, 314.9929f, 5.5689087f, 6.6683106f),
            new Rectangle(461.81015f, 350.87122f, 5.5689087f, 6.6683106f),
            new Rectangle(461.81015f, 356.44513f, 2.7844543f, 6.6683106f),
            new Rectangle(461.81015f, 359.2346f, 5.5689087f, 6.6683106f),
            new Rectangle(461.81015f, 364.8085f, 5.5689087f, 6.6683106f),
            new Rectangle(461.81015f, 370.38242f, 5.5689087f, 6.6683106f),
            new Rectangle(461.81015f, 375.95633f, 5.5689087f, 6.6683106f),
            new Rectangle(461.81015f, 381.53024f, 5.5689087f, 6.6683106f),
            new Rectangle(474.05057f, 132.9f, 2.7844543f, 6.6683106f),
            new Rectangle(474.05057f, 135.69044f, 3.3353271f, 6.6683106f),
            new Rectangle(474.05057f, 139.03178f, 5.5688934f, 6.6683106f),
            new Rectangle(474.05057f, 144.60669f, 2.2235565f, 6.6683106f),
            new Rectangle(474.05057f, 146.83626f, 5.5688934f, 6.6683106f),
            new Rectangle(474.05057f, 152.41116f, 5.5688934f, 6.6683106f),
            new Rectangle(474.05057f, 157.98607f, 5.5688934f, 6.6683106f),
            new Rectangle(474.05057f, 233.10406f, 5.5688934f, 6.6683106f),
            new Rectangle(474.05057f, 238.67897f, 5.5688934f, 6.6683106f),
            new Rectangle(474.05057f, 244.25388f, 5.5688934f, 6.6683106f),
            new Rectangle(474.05057f, 289.9118f, 5.5689087f, 6.6683106f),
            new Rectangle(474.05057f, 295.48672f, 5.5689087f, 6.6683106f),
            new Rectangle(474.05057f, 301.06165f, 2.7844543f, 6.6683106f),
            new Rectangle(474.05057f, 303.8521f, 5.5689087f, 6.6683106f),
            new Rectangle(474.05057f, 309.42703f, 5.5689087f, 6.6683106f),
            new Rectangle(474.05057f, 315.00195f, 5.5689087f, 6.6683106f),
            new Rectangle(474.05057f, 350.88028f, 5.5689087f, 6.6683106f),
            new Rectangle(474.05057f, 356.4552f, 2.7844543f, 6.6683106f),
            new Rectangle(474.05057f, 359.24567f, 5.5689087f, 6.6683106f),
            new Rectangle(474.05057f, 364.8206f, 5.5689087f, 6.6683106f),
            new Rectangle(474.05057f, 370.3955f, 5.5689087f, 6.6683106f),
            new Rectangle(474.05057f, 375.97043f, 5.5689087f, 6.6683106f),
            new Rectangle(474.05057f, 381.54535f, 5.5689087f, 6.6683106f),
            new Rectangle(487.4904f, 132.9f, 6.1197815f, 6.6683106f),
            new Rectangle(487.4904f, 139.02779f, 3.3353271f, 6.6683106f),
            new Rectangle(487.4904f, 142.37112f, 5.5688934f, 6.6683106f),
            new Rectangle(487.4904f, 147.94803f, 5.5688934f, 6.6683106f),
            new Rectangle(487.4904f, 153.52493f, 5.0079956f, 6.6683106f),
            new Rectangle(487.4904f, 158.54094f, 5.5688934f, 6.6683106f),
            new Rectangle(487.4904f, 233.05898f, 5.5688934f, 6.6683106f),
            new Rectangle(487.4904f, 238.63588f, 5.5688934f, 6.6683106f),
            new Rectangle(487.4904f, 244.21278f, 5.5688934f, 6.6683106f),
            new Rectangle(487.4904f, 287.0512f, 5.5689087f, 6.6683106f),
            new Rectangle(487.4904f, 292.6281f, 5.5689087f, 6.6683106f),
            new Rectangle(487.4904f, 298.20502f, 5.5689087f, 6.6683106f),
            new Rectangle(487.4904f, 303.78192f, 2.7844543f, 6.6683106f),
            new Rectangle(487.4904f, 306.57437f, 5.5689087f, 6.6683106f),
            new Rectangle(487.4904f, 312.15128f, 5.5689087f, 6.6683106f),
            new Rectangle(487.4904f, 317.72818f, 5.5689087f, 6.6683106f),
            new Rectangle(487.4904f, 350.84607f, 5.5689087f, 6.6683106f),
            new Rectangle(487.4904f, 356.42297f, 2.7844543f, 6.6683106f),
            new Rectangle(487.4904f, 359.21542f, 5.5689087f, 6.6683106f),
            new Rectangle(487.4904f, 364.79233f, 5.5689087f, 6.6683106f),
            new Rectangle(487.4904f, 370.36923f, 5.5689087f, 6.6683106f),
            new Rectangle(487.4904f, 375.94614f, 5.5689087f, 6.6683106f),
            new Rectangle(487.4904f, 381.52304f, 5.5689087f, 6.6683106f),
            new Rectangle(499.9703f, 132.9f, 6.6806793f, 6.6683106f),
            new Rectangle(499.9703f, 139.58568f, 5.5688934f, 6.6683106f),
            new Rectangle(499.9703f, 145.15958f, 3.3353271f, 6.6683106f),
            new Rectangle(499.9703f, 148.49991f, 2.7844543f, 6.6683106f),
            new Rectangle(499.9703f, 151.28937f, 5.5688934f, 6.6683106f),
            new Rectangle(499.9703f, 156.86327f, 5.5688934f, 6.6683106f),
            new Rectangle(499.9703f, 162.43716f, 5.5688934f, 6.6683106f),
            new Rectangle(499.9703f, 168.01106f, 2.2235565f, 6.6683106f),
            new Rectangle(499.9703f, 233.10905f, 5.5688934f, 6.6683106f),
            new Rectangle(499.9703f, 238.68295f, 5.5688934f, 6.6683106f),
            new Rectangle(499.9703f, 244.25685f, 5.5688934f, 6.6683106f),
            new Rectangle(499.9703f, 289.9148f, 5.5689087f, 6.6683106f),
            new Rectangle(499.9703f, 295.4887f, 5.5689087f, 6.6683106f),
            new Rectangle(499.9703f, 301.06262f, 2.7844543f, 6.6683106f),
            new Rectangle(499.9703f, 303.85208f, 5.5689087f, 6.6683106f),
            new Rectangle(499.9703f, 309.426f, 5.5689087f, 6.6683106f),
            new Rectangle(499.9703f, 314.9999f, 5.5689087f, 6.6683106f),
            new Rectangle(499.9703f, 350.87823f, 5.5689087f, 6.6683106f),
            new Rectangle(499.9703f, 356.45215f, 2.7844543f, 6.6683106f),
            new Rectangle(499.9703f, 359.2416f, 5.5689087f, 6.6683106f),
            new Rectangle(499.9703f, 364.81552f, 5.5689087f, 6.6683106f),
            new Rectangle(499.9703f, 370.38943f, 5.5689087f, 6.6683106f),
            new Rectangle(499.9703f, 375.96335f, 5.5689087f, 6.6683106f),
            new Rectangle(499.9703f, 381.53726f, 5.5689087f, 6.6683106f),
            new Rectangle(512.4502f, 132.9f, 7.231552f, 6.6683106f),
            new Rectangle(512.4502f, 140.13655f, 5.5688934f, 6.6683106f),
            new Rectangle(512.4502f, 145.71045f, 2.2235565f, 6.6683106f),
            new Rectangle(512.4502f, 147.93901f, 2.7844543f, 6.6683106f),
            new Rectangle(512.4502f, 150.72847f, 5.5688934f, 6.6683106f),
            new Rectangle(512.4502f, 156.30237f, 5.5688934f, 6.6683106f),
            new Rectangle(512.4502f, 161.87627f, 2.7844543f, 6.6683106f),
            new Rectangle(512.4502f, 164.63768f, 6.6806793f, 6.6683106f),
            new Rectangle(512.4502f, 171.32336f, 2.2235565f, 6.6683106f),
            new Rectangle(512.4502f, 173.55193f, 5.5688934f, 6.6683106f),
            new Rectangle(512.4502f, 179.12582f, 5.5688934f, 6.6683106f),
            new Rectangle(512.4502f, 184.69972f, 5.5688934f, 6.6683106f),
            new Rectangle(512.4502f, 190.27362f, 5.5688934f, 6.6683106f),
            new Rectangle(512.4502f, 195.84752f, 8.343323f, 6.6683106f),
            new Rectangle(512.4502f, 233.10704f, 5.5688934f, 6.6683106f),
            new Rectangle(512.4502f, 238.68094f, 5.5688934f, 6.6683106f),
            new Rectangle(512.4502f, 244.25484f, 5.5688934f, 6.6683106f),
            new Rectangle(512.4502f, 287.09326f, 5.5689087f, 6.6683106f),
            new Rectangle(512.4502f, 292.66718f, 5.5689087f, 6.6683106f),
            new Rectangle(512.4502f, 298.2411f, 5.5689087f, 6.6683106f),
            new Rectangle(512.4502f, 303.815f, 2.7844543f, 6.6683106f),
            new Rectangle(512.4502f, 306.60446f, 5.5689087f, 6.6683106f),
            new Rectangle(512.4502f, 312.17838f, 5.5689087f, 6.6683106f),
            new Rectangle(512.4502f, 317.7523f, 5.5689087f, 6.6683106f),
            new Rectangle(512.4502f, 350.8702f, 5.5689087f, 6.6683106f),
            new Rectangle(512.4502f, 356.44412f, 2.7844543f, 6.6683106f),
            new Rectangle(512.4502f, 359.23358f, 5.5689087f, 6.6683106f),
            new Rectangle(512.4502f, 364.8075f, 5.5689087f, 6.6683106f),
            new Rectangle(512.4502f, 370.3814f, 5.5689087f, 6.6683106f),
            new Rectangle(512.4502f, 375.95532f, 5.5689087f, 6.6683106f),
            new Rectangle(512.4502f, 381.52924f, 5.5689087f, 6.6683106f),
            new Rectangle(524.9301f, 132.9f, 6.6806793f, 6.6683106f),
            new Rectangle(524.9301f, 139.58568f, 5.5688934f, 6.6683106f),
            new Rectangle(524.9301f, 145.15958f, 5.5688934f, 6.6683106f),
            new Rectangle(524.9301f, 150.73347f, 2.2235565f, 6.6683106f),
            new Rectangle(524.9301f, 152.96204f, 5.5688934f, 6.6683106f),
            new Rectangle(524.9301f, 233.12007f, 5.5688934f, 6.6683106f),
            new Rectangle(524.9301f, 238.69397f, 5.5688934f, 6.6683106f),
            new Rectangle(524.9301f, 244.26787f, 5.5688934f, 6.6683106f),
            new Rectangle(524.9301f, 287.1063f, 5.5689087f, 6.6683106f),
            new Rectangle(524.9301f, 292.6802f, 5.5689087f, 6.6683106f),
            new Rectangle(524.9301f, 298.25412f, 5.5689087f, 6.6683106f),
            new Rectangle(524.9301f, 303.82803f, 2.7844543f, 6.6683106f),
            new Rectangle(524.9301f, 306.6175f, 5.5689087f, 6.6683106f),
            new Rectangle(524.9301f, 312.1914f, 5.5689087f, 6.6683106f),
            new Rectangle(524.9301f, 317.76532f, 5.5689087f, 6.6683106f),
            new Rectangle(524.9301f, 350.88324f, 5.5689087f, 6.6683106f),
            new Rectangle(524.9301f, 356.45715f, 2.7844543f, 6.6683106f),
            new Rectangle(524.9301f, 359.2466f, 5.5689087f, 6.6683106f),
            new Rectangle(524.9301f, 364.82053f, 5.5689087f, 6.6683106f),
            new Rectangle(524.9301f, 370.39444f, 5.5689087f, 6.6683106f),
            new Rectangle(524.9301f, 375.96835f, 5.5689087f, 6.6683106f),
            new Rectangle(524.9301f, 381.54227f, 5.5689087f, 6.6683106f),
            new Rectangle(537.41003f, 132.9f, 2.7844543f, 6.6683106f),
            new Rectangle(537.41003f, 135.68745f, 2.7844543f, 6.6683106f),
            new Rectangle(537.41003f, 138.47491f, 5.5688934f, 6.6683106f),
            new Rectangle(537.41003f, 144.04681f, 2.2235565f, 6.6683106f),
            new Rectangle(537.41003f, 146.27338f, 5.0079956f, 6.6683106f),
            new Rectangle(537.41003f, 233.15315f, 5.5688934f, 6.6683106f),
            new Rectangle(537.41003f, 238.72505f, 5.5688934f, 6.6683106f),
            new Rectangle(537.41003f, 244.29695f, 5.5688934f, 6.6683106f),
            new Rectangle(537.41003f, 287.13538f, 5.5689087f, 6.6683106f),
            new Rectangle(537.41003f, 292.70728f, 5.5689087f, 6.6683106f),
            new Rectangle(537.41003f, 298.27917f, 5.5689087f, 6.6683106f),
            new Rectangle(537.41003f, 303.85107f, 2.7844543f, 6.6683106f),
            new Rectangle(537.41003f, 306.63852f, 5.5689087f, 6.6683106f),
            new Rectangle(537.41003f, 312.21042f, 5.5689087f, 6.6683106f),
            new Rectangle(537.41003f, 317.78232f, 5.5689087f, 6.6683106f),
            new Rectangle(537.41003f, 350.9002f, 5.5689087f, 6.6683106f),
            new Rectangle(537.41003f, 356.4721f, 2.7844543f, 6.6683106f),
            new Rectangle(537.41003f, 359.25955f, 5.5689087f, 6.6683106f),
            new Rectangle(537.41003f, 364.83145f, 5.5689087f, 6.6683106f),
            new Rectangle(537.41003f, 370.40335f, 5.5689087f, 6.6683106f),
            new Rectangle(537.41003f, 375.97525f, 5.5689087f, 6.6683106f),
            new Rectangle(537.41003f, 381.54715f, 5.5689087f, 6.6683106f),
            new Rectangle(549.65045f, 132.9f, 7.79245f, 6.6683106f),
            new Rectangle(549.65045f, 140.69945f, 5.5688934f, 6.6683106f),
            new Rectangle(549.65045f, 146.27536f, 3.3353271f, 6.6683106f),
            new Rectangle(549.65045f, 149.6177f, 8.343323f, 6.6683106f),
            new Rectangle(549.65045f, 157.96805f, 5.5688934f, 6.6683106f),
            new Rectangle(549.65045f, 163.54396f, 5.5688934f, 6.6683106f),
            new Rectangle(549.65045f, 169.11987f, 5.0079956f, 6.6683106f),
            new Rectangle(549.65045f, 233.08005f, 5.5688934f, 6.6683106f),
            new Rectangle(549.65045f, 238.65596f, 5.5688934f, 6.6683106f),
            new Rectangle(549.65045f, 244.23187f, 5.5688934f, 6.6683106f),
            new Rectangle(549.65045f, 287.0703f, 5.5689087f, 6.6683106f),
            new Rectangle(549.65045f, 292.6462f, 5.5689087f, 6.6683106f),
            new Rectangle(549.65045f, 298.2221f, 5.5689087f, 6.6683106f),
            new Rectangle(549.65045f, 303.798f, 2.7844543f, 6.6683106f),
            new Rectangle(549.65045f, 306.58948f, 5.5689087f, 6.6683106f),
            new Rectangle(549.65045f, 312.16537f, 5.5689087f, 6.6683106f),
            new Rectangle(549.65045f, 317.74127f, 5.5689087f, 6.6683106f),
            new Rectangle(549.65045f, 350.85916f, 5.5689087f, 6.6683106f),
            new Rectangle(549.65045f, 356.43506f, 2.7844543f, 6.6683106f),
            new Rectangle(549.65045f, 359.22653f, 5.5689087f, 6.6683106f),
            new Rectangle(549.65045f, 364.80243f, 5.5689087f, 6.6683106f),
            new Rectangle(549.65045f, 370.37833f, 5.5689087f, 6.6683106f),
            new Rectangle(549.65045f, 375.95422f, 5.5689087f, 6.6683106f),
            new Rectangle(549.65045f, 381.53012f, 5.5689087f, 6.6683106f),
            new Rectangle(518.2708f, 412.49863f, 6.680664f, 6.6683106f),
            new Rectangle(518.2708f, 419.1803f, 5.0079956f, 6.6683106f),
            new Rectangle(518.2708f, 424.1893f, 5.0079956f, 6.6683106f),
            new Rectangle(518.2708f, 429.1983f, 5.5689087f, 6.6683106f),
            new Rectangle(518.2708f, 434.7682f, 2.2235413f, 6.6683106f),
            new Rectangle(518.2708f, 436.99274f, 2.2235413f, 6.6683106f),
            new Rectangle(518.2708f, 439.2173f, 5.5689087f, 6.6683106f),
            new Rectangle(518.2708f, 444.78717f, 5.5689087f, 6.6683106f),
            new Rectangle(518.2708f, 450.35706f, 2.7844543f, 6.6683106f),
            new Rectangle(76.27562f, 147.47928f, 7.231552f, 6.9438605f),
            new Rectangle(76.27562f, 154.71384f, 5.5688934f, 6.9438605f),
            new Rectangle(76.27562f, 160.28574f, 5.5688934f, 6.9438605f),
            new Rectangle(76.27562f, 165.85764f, 6.1197815f, 6.9438605f),
            new Rectangle(76.27562f, 171.98042f, 3.896225f, 6.9438605f),
            new Rectangle(76.27562f, 175.87965f, 5.5688934f, 6.9438605f),
            new Rectangle(76.27562f, 181.45155f, 5.5688934f, 6.9438605f),
            new Rectangle(76.27562f, 187.02345f, 5.5688934f, 6.9438605f),
            new Rectangle(76.27562f, 192.42207f, 2.7844543f, 6.9438605f),
            new Rectangle(76.27562f, 195.18349f, 6.1197815f, 6.9438605f),
            new Rectangle(76.27562f, 201.30627f, 3.3353271f, 6.9438605f),
            new Rectangle(76.27562f, 204.6446f, 2.7844543f, 6.9438605f),
            new Rectangle(76.27562f, 207.40602f, 3.3353271f, 6.9438605f),
            new Rectangle(76.27562f, 210.74435f, 6.1197815f, 6.9438605f),
            new Rectangle(76.27562f, 216.86714f, 5.5688934f, 6.9438605f),
            new Rectangle(76.27562f, 222.43904f, 2.7844543f, 6.9438605f),
            new Rectangle(76.27562f, 225.20045f, 3.896225f, 6.9438605f),
            new Rectangle(76.27562f, 229.09969f, 5.5688934f, 6.9438605f),
            new Rectangle(76.27562f, 234.67159f, 6.1197815f, 6.9438605f),
            new Rectangle(76.27562f, 240.79437f, 2.7844543f, 6.9438605f),
            new Rectangle(76.27562f, 243.58183f, 2.7844543f, 6.9438605f),
            new Rectangle(76.27562f, 246.3693f, 5.5688934f, 6.9438605f),
            new Rectangle(76.27562f, 251.9412f, 5.5689087f, 6.9438605f),
            new Rectangle(76.27562f, 257.5131f, 2.7844543f, 6.9438605f),
            new Rectangle(76.27562f, 260.2745f, 6.1197815f, 6.9438605f),
            new Rectangle(76.27562f, 266.39728f, 6.1197815f, 6.9438605f),
            new Rectangle(76.27562f, 272.52005f, 3.3353271f, 6.9438605f),
            new Rectangle(76.27562f, 275.85837f, 5.5689087f, 6.9438605f),
            new Rectangle(76.27562f, 281.43027f, 2.7844543f, 6.9438605f),
            new Rectangle(76.27562f, 284.2177f, 6.1197815f, 6.9438605f),
            new Rectangle(76.27562f, 290.34048f, 5.5689087f, 6.9438605f),
            new Rectangle(76.27562f, 295.91238f, 6.1197815f, 6.9438605f),
            new Rectangle(76.27562f, 302.03516f, 2.7844543f, 6.9438605f),
            new Rectangle(76.27562f, 304.79657f, 3.3353271f, 6.9438605f),
            new Rectangle(76.27562f, 308.1349f, 3.8962097f, 6.9438605f),
            new Rectangle(76.27562f, 312.03412f, 6.1197815f, 6.9438605f),
            new Rectangle(76.27562f, 318.1569f, 8.904236f, 6.9438605f),
            new Rectangle(76.27562f, 327.06412f, 2.7844543f, 6.9438605f),
            new Rectangle(76.27562f, 329.82553f, 3.3353271f, 6.9438605f),
            new Rectangle(76.27562f, 333.16385f, 6.1197815f, 6.9438605f),
            new Rectangle(76.27562f, 339.28662f, 5.5689087f, 6.9438605f),
            new Rectangle(76.27562f, 344.85852f, 2.7844543f, 6.9438605f),
            new Rectangle(76.27562f, 347.61993f, 5.5689087f, 6.9438605f),
            new Rectangle(76.27562f, 353.19183f, 6.1197815f, 6.9438605f),
            new Rectangle(76.27562f, 359.3146f, 3.8962097f, 6.9438605f),
            new Rectangle(76.27562f, 363.21384f, 5.5689087f, 6.9438605f),
            new Rectangle(76.27562f, 368.67255f, 5.5689087f, 6.9438605f),
            new Rectangle(76.27562f, 374.24445f, 5.5689087f, 6.9438605f),
            new Rectangle(76.27562f, 379.64307f, 2.7844543f, 6.9438605f),
            new Rectangle(76.27562f, 382.40448f, 5.5689087f, 6.9438605f),
            new Rectangle(76.27562f, 387.97638f, 5.5689087f, 6.9438605f),
            new Rectangle(76.27562f, 393.54828f, 3.8962097f, 6.9438605f),
            new Rectangle(76.27562f, 397.4475f, 3.8962097f, 6.9438605f),
            new Rectangle(76.27562f, 401.34674f, 2.7844543f, 6.9438605f),
            new Rectangle(76.27562f, 404.1342f, 5.5689087f, 6.9438605f),
            new Rectangle(76.27562f, 409.7061f, 6.1197815f, 6.9438605f),
            new Rectangle(76.27562f, 415.82886f, 2.7844543f, 6.9438605f),
            new Rectangle(76.27562f, 418.59027f, 6.1197815f, 6.9438605f),
            new Rectangle(76.27562f, 424.71304f, 6.1197815f, 6.9438605f),
            new Rectangle(76.27562f, 430.83582f, 3.3353271f, 6.9438605f),
            new Rectangle(76.27562f, 434.17413f, 2.7844543f, 6.9438605f),
            new Rectangle(76.27562f, 436.93555f, 6.1197815f, 6.9438605f),
            new Rectangle(76.27562f, 443.05832f, 5.5689087f, 6.9438605f),
            new Rectangle(76.27562f, 448.45694f, 2.7844543f, 6.9438605f),
            new Rectangle(88.9359f, 186.0589f, 7.231552f, 6.9438605f),
            new Rectangle(88.9359f, 193.29646f, 7.231552f, 6.9438605f),
            new Rectangle(88.9359f, 200.53403f, 7.231552f, 6.9438605f),
            new Rectangle(88.9359f, 207.77159f, 6.6806793f, 6.9438605f),
            new Rectangle(88.9359f, 214.45827f, 7.231552f, 6.9438605f),
            new Rectangle(88.9359f, 221.69583f, 2.7844543f, 6.9438605f),
            new Rectangle(88.9359f, 224.45724f, 3.3353271f, 6.9438605f),
            new Rectangle(88.9359f, 227.79858f, 5.5688934f, 6.9438605f),
            new Rectangle(88.9359f, 233.37349f, 5.5688934f, 6.9438605f),
            new Rectangle(88.9359f, 238.9484f, 5.5688934f, 6.9438605f),
            new Rectangle(88.9359f, 244.5233f, 5.5688934f, 6.9438605f),
            new Rectangle(88.9359f, 250.0982f, 2.7844543f, 6.9438605f),
            new Rectangle(88.9359f, 252.88866f, 2.7844543f, 6.9438605f),
            new Rectangle(88.9359f, 255.65007f, 6.119766f, 6.9438605f),
            new Rectangle(88.9359f, 261.77585f, 6.1197815f, 6.9438605f),
            new Rectangle(88.9359f, 267.90164f, 3.3353271f, 6.9438605f),
            new Rectangle(88.9359f, 271.24298f, 5.5689087f, 6.9438605f),
            new Rectangle(88.9359f, 276.8179f, 2.7844543f, 6.9438605f),
            new Rectangle(88.9359f, 279.60837f, 2.7844543f, 6.9438605f),
            new Rectangle(88.9359f, 282.36978f, 5.5689087f, 6.9438605f),
            new Rectangle(88.9359f, 287.9447f, 6.1197815f, 6.9438605f),
            new Rectangle(88.9359f, 294.0705f, 3.8962097f, 6.9438605f),
            new Rectangle(88.9359f, 297.97272f, 5.5689087f, 6.9438605f),
            new Rectangle(88.9359f, 303.43146f, 5.5689087f, 6.9438605f),
            new Rectangle(88.9359f, 309.00638f, 5.5689087f, 6.9438605f),
            new Rectangle(88.9359f, 314.40503f, 2.7844543f, 6.9438605f),
            new Rectangle(88.9359f, 317.16644f, 6.1197815f, 6.9438605f),
            new Rectangle(88.9359f, 323.29224f, 6.1197815f, 6.9438605f),
            new Rectangle(88.9359f, 329.41803f, 6.1197815f, 6.9438605f),
            new Rectangle(88.9359f, 335.54382f, 6.1197815f, 6.9438605f),
            new Rectangle(88.9359f, 341.66962f, 2.7844543f, 6.9438605f),
            new Rectangle(88.9359f, 344.46008f, 5.5689087f, 6.9438605f),
            new Rectangle(88.9359f, 350.035f, 3.3353271f, 6.9438605f),
            new Rectangle(88.9359f, 353.37634f, 2.7844543f, 6.9438605f),
            new Rectangle(88.9359f, 356.1668f, 6.1197815f, 6.9438605f),
            new Rectangle(88.9359f, 362.2926f, 6.1197815f, 6.9438605f),
            new Rectangle(88.9359f, 368.4184f, 2.7844543f, 6.9438605f),
            new Rectangle(88.9359f, 371.1798f, 7.2315674f, 6.9438605f),
            new Rectangle(88.9359f, 378.41736f, 5.8493347f, 6.9438605f),
            new Rectangle(88.9359f, 384.2727f, 5.5689087f, 6.9438605f),
            new Rectangle(88.9359f, 389.84763f, 5.5689087f, 6.9438605f),
            new Rectangle(88.9359f, 395.42255f, 5.5689087f, 6.9438605f),
            new Rectangle(88.9359f, 400.99747f, 5.5689087f, 6.9438605f),
            new Rectangle(88.9359f, 406.5724f, 3.3353271f, 6.9438605f),
            new Rectangle(172.91153f, 423.59833f, 5.5689087f, 6.6683106f),
            new Rectangle(172.91153f, 429.17725f, 5.5689087f, 6.6683106f),
            new Rectangle(172.91153f, 434.75616f, 7.2315674f, 6.6683106f),
            new Rectangle(254.75186f, 414.95853f, 8.343323f, 6.6683106f),
            new Rectangle(254.75186f, 423.30685f, 5.5689087f, 6.6683106f),
            new Rectangle(254.75186f, 428.88077f, 5.5689087f, 6.6683106f),
            new Rectangle(254.75186f, 434.45468f, 2.2235413f, 6.6683106f),
            new Rectangle(254.75186f, 436.68323f, 5.5689087f, 6.6683106f),
            new Rectangle(254.75186f, 442.25714f, 8.343323f, 6.6683106f),
            new Rectangle(392.75232f, 422.4585f, 7.2315674f, 6.6683106f),
            new Rectangle(392.75232f, 429.70108f, 2.2235413f, 6.6683106f),
            new Rectangle(392.75232f, 431.93564f, 5.5689087f, 6.6683106f),
            new Rectangle(392.75232f, 437.51556f, 5.5689087f, 6.6683106f),
            new Rectangle(554.5925f, 464.88f, 3.5270386f, 6.0470705f),
            new Rectangle(576.26807f, 121.08f, 4.0859985f, 5.4315f),
            new Rectangle(576.26807f, 125.1588f, 5.723999f, 5.4315f),
            new Rectangle(576.26807f, 130.8756f, 4.0859985f, 5.4315f),
            new Rectangle(576.26807f, 134.95439f, 3.1679993f, 5.4315f),
            new Rectangle(576.26807f, 138.198f, 6.9389954f, 5.4315f),
            new Rectangle(576.26807f, 145.16219f, 5.4089966f, 5.4315f),
            new Rectangle(576.26807f, 150.56578f, 3.5460052f, 5.4315f),
            new Rectangle(576.26807f, 154.10458f, 5.4089966f, 5.4315f),
            new Rectangle(576.26807f, 159.50638f, 3.1679993f, 5.4315f),
            new Rectangle(576.26807f, 162.74998f, 5.4629974f, 5.4315f),
            new Rectangle(576.26807f, 168.20578f, 3.1679993f, 5.4315f),
            new Rectangle(576.26807f, 171.36658f, 3.1679993f, 5.4315f),
            new Rectangle(576.26807f, 174.61018f, 3.8430023f, 5.4315f),
            new Rectangle(576.26807f, 178.44598f, 5.3639984f, 5.4315f),
            new Rectangle(576.26807f, 183.80278f, 4.6889954f, 5.4315f),
            new Rectangle(576.26807f, 188.48457f, 5.3639984f, 5.4315f),
            new Rectangle(576.26807f, 193.84137f, 5.4089966f, 5.4315f),
            new Rectangle(576.26807f, 199.24316f, 3.8430023f, 5.4315f),
            new Rectangle(576.26807f, 203.07896f, 4.6889954f, 5.4315f),
            new Rectangle(576.26807f, 207.76076f, 5.697006f, 5.4315f),
            new Rectangle(576.26807f, 213.45056f, 5.3639984f, 5.4315f),
            new Rectangle(576.26807f, 218.80736f, 3.8430023f, 5.4315f),
            new Rectangle(576.26807f, 222.70976f, 4.6889954f, 5.4315f),
            new Rectangle(576.26807f, 227.39156f, 3.1679993f, 5.4315f),
            new Rectangle(576.26807f, 230.63516f, 2.4660034f, 5.4315f),
            new Rectangle(576.26807f, 233.15157f, 5.697006f, 5.4315f),
            new Rectangle(576.26807f, 238.85307f, 3.1679993f, 5.4315f),
            new Rectangle(576.26807f, 242.09668f, 3.5460052f, 5.4315f),
            new Rectangle(576.26807f, 245.63548f, 5.697006f, 5.4315f),
            new Rectangle(576.26807f, 251.32529f, 5.3640137f, 5.4315f),
            new Rectangle(576.26807f, 256.6821f, 3.1679993f, 5.4315f),
            new Rectangle(576.26807f, 259.9257f, 5.6069946f, 5.4315f),
            new Rectangle(576.26807f, 265.52548f, 2.4660034f, 5.4315f),
            new Rectangle(576.26807f, 268.04187f, 3.1679993f, 5.4315f),
            new Rectangle(576.26807f, 271.20267f, 3.1679993f, 5.4315f),
            new Rectangle(576.26807f, 274.36346f, 5.3640137f, 5.4315f),
            new Rectangle(576.26807f, 279.72028f, 3.842987f, 5.4315f),
            new Rectangle(576.26807f, 283.55606f, 5.3640137f, 5.4315f),
            new Rectangle(576.26807f, 288.91287f, 5.696991f, 5.4315f),
            new Rectangle(576.26807f, 294.60266f, 3.54599f, 5.4315f),
            new Rectangle(576.26807f, 298.14145f, 3.1679993f, 5.4315f),
            new Rectangle(576.26807f, 301.38504f, 4.6889954f, 5.4315f),
            new Rectangle(576.26807f, 306.06683f, 5.4630127f, 5.4315f),
            new Rectangle(576.26807f, 311.52264f, 5.696991f, 5.4315f),
            new Rectangle(576.26807f, 317.21243f, 5.696991f, 5.4315f),
            new Rectangle(576.26807f, 322.90222f, 3.54599f, 5.4315f),
            new Rectangle(576.26807f, 326.441f, 3.842987f, 5.4315f),
            new Rectangle(576.26807f, 330.2768f, 2.4660034f, 5.4315f),
            new Rectangle(576.26807f, 332.79318f, 5.3640137f, 5.4315f),
            new Rectangle(576.26807f, 338.15f, 4.6889954f, 5.4315f),
            new Rectangle(576.26807f, 342.8318f, 3.1679993f, 5.4315f),
            new Rectangle(576.26807f, 346.07538f, 5.4089966f, 5.4315f),
            new Rectangle(576.26807f, 351.47717f, 3.842987f, 5.4315f),
            new Rectangle(576.26807f, 355.31296f, 5.3640137f, 5.4315f),
            new Rectangle(576.26807f, 360.66977f, 3.1679993f, 5.4315f),
            new Rectangle(576.26807f, 363.91336f, 5.3640137f, 5.4315f),
            new Rectangle(576.26807f, 369.27017f, 5.328003f, 5.4315f),
            new Rectangle(576.26807f, 374.59097f, 3.54599f, 5.4315f),
            new Rectangle(576.26807f, 378.12976f, 3.842987f, 5.4315f),
            new Rectangle(576.26807f, 381.96555f, 5.4089966f, 5.4315f),
            new Rectangle(576.26807f, 387.36734f, 4.6889954f, 5.4315f),
            new Rectangle(576.26807f, 392.04913f, 3.54599f, 5.4315f),
            new Rectangle(576.26807f, 395.58792f, 5.3640137f, 5.4315f),
            new Rectangle(576.26807f, 400.99063f, 5.6069946f, 5.4315f),
            new Rectangle(576.26807f, 406.59042f, 3.1679993f, 5.4315f),
            new Rectangle(576.26807f, 409.834f, 3.1679993f, 5.4315f),
            new Rectangle(576.26807f, 412.9948f, 3.842987f, 5.4315f),
            new Rectangle(576.26807f, 416.8306f, 5.4630127f, 5.4315f),
            new Rectangle(576.26807f, 422.2864f, 8.756989f, 5.4315f),
            new Rectangle(576.26807f, 431.0362f, 3.1679993f, 5.4315f),
            new Rectangle(576.26807f, 434.2798f, 5.6879883f, 5.4315f),
            new Rectangle(576.26807f, 439.96057f, 5.696991f, 5.4315f),
            new Rectangle(576.26807f, 445.65036f, 3.842987f, 5.4315f),
            new Rectangle(576.26807f, 449.48615f, 5.4630127f, 5.4315f),
            new Rectangle(576.26807f, 454.94196f, 4.6889954f, 5.4315f),
            new Rectangle(576.26807f, 459.62375f, 3.54599f, 5.4315f),
            new Rectangle(576.26807f, 463.16254f, 5.4089966f, 5.4315f),
            new Rectangle(576.26807f, 468.56433f, 3.54599f, 5.4315f),
            new Rectangle(576.26807f, 472.10312f, 3.1679993f, 5.4315f),
            new Rectangle(587.18774f, 121.08f, 4.0859985f, 5.4315f),
            new Rectangle(587.18774f, 125.154305f, 4.1310043f, 5.4315f),
            new Rectangle(587.18774f, 129.2736f, 6.156006f, 5.4315f),
            new Rectangle(587.18774f, 135.4575f, 4.6889954f, 5.4315f),
            new Rectangle(587.18774f, 140.13751f, 2.4660034f, 5.4315f),
            new Rectangle(587.18774f, 142.65392f, 5.3639984f, 5.4315f),
            new Rectangle(587.18774f, 147.9963f, 5.697006f, 5.4315f),
            new Rectangle(587.18774f, 153.68161f, 4.6889954f, 5.4315f),
            new Rectangle(587.18774f, 158.35892f, 5.3639984f, 5.4315f),
            new Rectangle(587.18774f, 163.71121f, 3.1679993f, 5.4315f),
            new Rectangle(587.18774f, 166.89542f, 5.4089966f, 5.4315f),
            new Rectangle(587.18774f, 172.29271f, 5.697006f, 5.4315f),
            new Rectangle(587.18774f, 177.97801f, 5.6069946f, 5.4315f),
            new Rectangle(587.18774f, 183.57332f, 3.1679993f, 5.4315f),
            new Rectangle(587.18774f, 186.75752f, 3.5460052f, 5.4315f),
            new Rectangle(587.18774f, 190.29182f, 5.3639984f, 5.4315f),
            new Rectangle(587.18774f, 195.64412f, 4.6889954f, 5.4315f),
            new Rectangle(587.18774f, 200.32143f, 5.697006f, 5.4315f),
            new Rectangle(587.18774f, 206.00673f, 5.697006f, 5.4315f),
            new Rectangle(587.18774f, 211.69203f, 5.4629974f, 5.4315f),
            new Rectangle(587.18774f, 217.14333f, 2.4660034f, 5.4315f),
            new Rectangle(587.18774f, 219.65973f, 5.4629974f, 5.4315f),
            new Rectangle(587.18774f, 225.12003f, 5.6069946f, 5.4315f),
            new Rectangle(587.18774f, 230.71533f, 5.328003f, 5.4315f),
            new Rectangle(587.18774f, 236.03163f, 3.1679993f, 5.4315f),
            new Rectangle(587.18774f, 239.21584f, 2.4660034f, 5.4315f),
            new Rectangle(587.18774f, 241.73224f, 5.697006f, 5.4315f),
            new Rectangle(587.18774f, 247.43375f, 3.1679993f, 5.4315f),
            new Rectangle(587.18774f, 250.61795f, 5.6879883f, 5.4315f),
            new Rectangle(587.18774f, 256.29425f, 5.696991f, 5.4315f),
            new Rectangle(587.18774f, 261.97955f, 3.842987f, 5.4315f),
            new Rectangle(587.18774f, 265.81085f, 5.4630127f, 5.4315f),
            new Rectangle(587.18774f, 271.26215f, 5.6069946f, 5.4315f),
            new Rectangle(587.18774f, 276.85745f, 5.3640137f, 5.4315f),
            new Rectangle(587.18774f, 282.20975f, 4.0859985f, 5.4315f),
            new Rectangle(587.18774f, 286.28406f, 6.156006f, 5.4315f),
            new Rectangle(587.18774f, 292.46796f, 3.54599f, 5.4315f),
            new Rectangle(587.18774f, 296.00226f, 5.4089966f, 5.4315f),
            new Rectangle(587.18774f, 301.39957f, 3.54599f, 5.4315f),
            new Rectangle(587.18774f, 304.93387f, 2.4660034f, 5.4315f),
            new Rectangle(587.18774f, 307.4503f, 4.6889954f, 5.4315f),
            new Rectangle(587.18774f, 312.1276f, 3.54599f, 5.4315f),
            new Rectangle(587.18774f, 315.6619f, 2.4660034f, 5.4315f),
            new Rectangle(587.18774f, 318.1783f, 4.6889954f, 5.4315f),
            new Rectangle(587.18774f, 322.8583f, 5.4089966f, 5.4315f),
            new Rectangle(587.18774f, 328.2556f, 2.4660034f, 5.4315f),
            new Rectangle(587.18774f, 330.77203f, 3.1679993f, 5.4315f),
            new Rectangle(587.18774f, 333.95624f, 5.6069946f, 5.4315f),
            new Rectangle(587.18774f, 339.55154f, 5.4630127f, 5.4315f),
            new Rectangle(587.18774f, 345.00284f, 4.6889954f, 5.4315f),
            new Rectangle(587.18774f, 349.68015f, 5.328003f, 5.4315f),
            new Rectangle(587.18774f, 354.99646f, 5.3640137f, 5.4315f),
            new Rectangle(587.18774f, 360.34875f, 3.54599f, 5.4315f),
            new Rectangle(587.18774f, 363.88306f, 5.6069946f, 5.4315f),
            new Rectangle(587.18774f, 369.47836f, 5.4630127f, 5.4315f),
            new Rectangle(587.18774f, 374.92966f, 5.4630127f, 5.4315f),
            new Rectangle(587.18774f, 380.38095f, 5.328003f, 5.4315f),
            new Rectangle(587.18774f, 385.69727f, 4.131012f, 5.4315f),
            new Rectangle(587.18774f, 389.81656f, 3.276001f, 5.4315f),
            new Rectangle(587.18774f, 393.11868f, 3.1679993f, 5.4315f),
            new Rectangle(587.18774f, 396.3029f, 5.723999f, 5.4315f),
            new Rectangle(587.18774f, 402.0152f, 5.723999f, 5.4315f),
            new Rectangle(587.18774f, 407.7275f, 5.723999f, 5.4315f),
            new Rectangle(587.18774f, 413.49023f, 5.723999f, 5.4315f),
            new Rectangle(587.18774f, 419.20255f, 4.0859985f, 5.4315f),
            new Rectangle(587.18774f, 423.27686f, 3.276001f, 5.4315f),
            new Rectangle(587.18774f, 426.57898f, 3.1679993f, 5.4315f),
            new Rectangle(610.1675f, 121.08f, 4.0859985f, 5.4315f),
            new Rectangle(610.1675f, 125.1597f, 5.723999f, 5.4315f),
            new Rectangle(610.1675f, 130.8774f, 4.0859985f, 5.4315f),
            new Rectangle(610.1675f, 134.95709f, 3.1679993f, 5.4315f),
            new Rectangle(610.1675f, 142.16069f, 5.6069946f, 5.4315f),
            new Rectangle(610.1675f, 147.76138f, 3.1679993f, 5.4315f),
            new Rectangle(610.1675f, 154.96498f, 3.8430023f, 5.4315f),
            new Rectangle(610.1675f, 158.80168f, 5.3639984f, 5.4315f),
            new Rectangle(610.1675f, 164.15938f, 5.6069946f, 5.4315f),
            new Rectangle(610.1675f, 169.76007f, 3.8430023f, 5.4315f),
            new Rectangle(610.1675f, 173.66248f, 5.3639984f, 5.4315f),
            new Rectangle(610.1675f, 179.02017f, 4.6889954f, 5.4315f),
            new Rectangle(610.1675f, 183.70287f, 5.3639984f, 5.4315f),
            new Rectangle(610.1675f, 189.06056f, 5.697006f, 5.4315f),
            new Rectangle(610.1675f, 194.75127f, 3.5460052f, 5.4315f),
            new Rectangle(610.1675f, 198.29097f, 4.6889954f, 5.4315f),
            new Rectangle(610.1675f, 202.97366f, 3.1679993f, 5.4315f),
            new Rectangle(610.1675f, 210.17726f, 3.5460052f, 5.4315f),
            new Rectangle(610.1675f, 213.71696f, 5.697006f, 5.4315f),
            new Rectangle(610.1675f, 219.40767f, 5.3639984f, 5.4315f),
            new Rectangle(610.1675f, 224.76537f, 3.1679993f, 5.4315f),
            new Rectangle(610.1675f, 231.96896f, 5.4089966f, 5.4315f),
            new Rectangle(610.1675f, 237.43286f, 4.6889954f, 5.4315f),
            new Rectangle(610.1675f, 242.11555f, 4.6889954f, 5.4315f),
            new Rectangle(610.1675f, 246.79825f, 5.697006f, 5.4315f),
            new Rectangle(610.1675f, 252.48895f, 3.842987f, 5.4315f),
            new Rectangle(610.1675f, 256.32565f, 5.4089966f, 5.4315f),
            new Rectangle(610.1675f, 261.72836f, 4.6889954f, 5.4315f),
            new Rectangle(610.1675f, 266.41107f, 5.328003f, 5.4315f),
            new Rectangle(610.1675f, 271.73276f, 3.1679993f, 5.4315f),
            new Rectangle(610.1675f, 278.93637f, 4.6889954f, 5.4315f),
            new Rectangle(610.1675f, 283.61908f, 5.4089966f, 5.4315f),
            new Rectangle(610.1675f, 289.0218f, 2.4660034f, 5.4315f),
            new Rectangle(610.1675f, 291.53818f, 4.6889954f, 5.4315f),
            new Rectangle(610.1675f, 296.1579f, 5.696991f, 5.4315f),
            new Rectangle(610.1675f, 301.8486f, 2.4660034f, 5.4315f),
            new Rectangle(610.1675f, 304.365f, 5.4089966f, 5.4315f),
            new Rectangle(610.1675f, 309.7677f, 3.54599f, 5.4315f),
            new Rectangle(610.1675f, 313.3074f, 5.3640137f, 5.4315f),
            new Rectangle(610.1675f, 318.6651f, 5.6069946f, 5.4315f),
            new Rectangle(610.1675f, 324.2658f, 3.1679993f, 5.4315f),
            new Rectangle(610.1675f, 331.46942f, 3.54599f, 5.4315f),
            new Rectangle(610.1675f, 335.00912f, 5.696991f, 5.4315f),
            new Rectangle(610.1675f, 340.69983f, 3.842987f, 5.4315f),
            new Rectangle(610.1675f, 344.53653f, 5.4630127f, 5.4315f),
            new Rectangle(610.1675f, 349.99323f, 5.696991f, 5.4315f),
            new Rectangle(610.1675f, 355.68393f, 5.6069946f, 5.4315f),
            new Rectangle(610.1675f, 361.28464f, 5.696991f, 5.4315f),
            new Rectangle(610.1675f, 366.97534f, 3.1679993f, 5.4315f),
            new Rectangle(610.1675f, 374.17896f, 3.54599f, 5.4315f),
            new Rectangle(610.1675f, 377.71866f, 5.696991f, 5.4315f),
            new Rectangle(610.1675f, 383.40936f, 5.3640137f, 5.4315f),
            new Rectangle(610.1675f, 388.76706f, 3.1679993f, 5.4315f),
            new Rectangle(610.1675f, 395.97067f, 3.1679993f, 5.4315f),
            new Rectangle(610.1675f, 399.1324f, 5.4630127f, 5.4315f),
            new Rectangle(610.1675f, 404.58908f, 3.842987f, 5.4315f),
            new Rectangle(610.1675f, 408.42578f, 8.756989f, 5.4315f),
            new Rectangle(610.1675f, 417.17648f, 5.696991f, 5.4315f),
            new Rectangle(610.1675f, 422.8672f, 2.4660034f, 5.4315f),
            new Rectangle(610.1675f, 425.38358f, 5.4089966f, 5.4315f),
            new Rectangle(610.1675f, 430.7863f, 3.1679993f, 5.4315f),
            new Rectangle(610.1675f, 437.9305f, 3.1679993f, 5.4315f),
            new Rectangle(610.1675f, 441.09222f, 5.4630127f, 5.4315f),
            new Rectangle(610.1675f, 446.54892f, 3.842987f, 5.4315f),
            new Rectangle(610.1675f, 450.38562f, 3.1679993f, 5.4315f),
            new Rectangle(610.1675f, 457.58923f, 3.54599f, 5.4315f),
            new Rectangle(610.1675f, 461.12894f, 5.696991f, 5.4315f),
            new Rectangle(610.1675f, 466.77103f, 5.3640137f, 5.4315f),
            new Rectangle(610.1675f, 472.12872f, 3.1679993f, 5.4315f),
            new Rectangle(621.08716f, 121.08f, 5.6070023f, 5.4315f),
            new Rectangle(621.08716f, 126.659996f, 5.364006f, 5.4315f),
            new Rectangle(621.08716f, 132.0024f, 3.5460052f, 5.4315f),
            new Rectangle(621.08716f, 135.5421f, 5.3639984f, 5.4315f),
            new Rectangle(621.08716f, 140.88449f, 3.8430023f, 5.4315f),
            new Rectangle(621.08716f, 144.7266f, 8.757004f, 5.4315f),
            new Rectangle(621.08716f, 153.4899f, 2.4660034f, 5.4315f),
            new Rectangle(621.08716f, 155.9901f, 5.697006f, 5.4315f),
            new Rectangle(621.08716f, 161.6916f, 5.4089966f, 5.4315f),
            new Rectangle(621.08716f, 167.09521f, 3.5460052f, 5.4315f),
            new Rectangle(621.08716f, 170.63492f, 2.4660034f, 5.4315f),
            new Rectangle(621.08716f, 173.13512f, 5.4629974f, 5.4315f),
            new Rectangle(621.08716f, 178.59543f, 5.697006f, 5.4315f),
            new Rectangle(621.08716f, 184.29694f, 3.1679993f, 5.4315f),
            new Rectangle(621.08716f, 187.48114f, 5.4629974f, 5.4315f),
            new Rectangle(621.08716f, 192.94144f, 3.1679993f, 5.4315f),
            new Rectangle(621.08716f, 196.12563f, 3.1679993f, 5.4315f),
            new Rectangle(621.08716f, 199.30983f, 3.5460052f, 5.4315f),
            new Rectangle(621.08716f, 202.84953f, 5.697006f, 5.4315f),
            new Rectangle(621.08716f, 208.55104f, 5.3639984f, 5.4315f),
            new Rectangle(621.08716f, 213.89343f, 3.1679993f, 5.4315f),
            new Rectangle(621.08716f, 217.07764f, 4.6889954f, 5.4315f),
            new Rectangle(621.08716f, 221.75764f, 5.4089966f, 5.4315f),
            new Rectangle(621.08716f, 227.16125f, 8.757004f, 5.4315f),
            new Rectangle(621.08716f, 235.86426f, 5.6069946f, 5.4315f),
            new Rectangle(621.08716f, 241.44426f, 2.4660034f, 5.4315f),
            new Rectangle(621.08716f, 243.94446f, 5.3639984f, 5.4315f),
            new Rectangle(621.08716f, 249.28685f, 2.4210052f, 5.4315f),
            new Rectangle(621.08716f, 251.69075f, 4.6890106f, 5.4315f),
            new Rectangle(621.08716f, 256.37073f, 3.1679993f, 5.4315f),
            new Rectangle(621.08716f, 259.55493f, 4.6889954f, 5.4315f),
            new Rectangle(621.08716f, 264.23492f, 2.4660034f, 5.4315f),
            new Rectangle(621.08716f, 266.75134f, 4.725006f, 5.4315f),
            new Rectangle(621.08716f, 271.51053f, 5.3640137f, 5.4315f),
            new Rectangle(621.08716f, 276.85294f, 3.276001f, 5.4315f),
            new Rectangle(621.08716f, 280.16315f, 3.1679993f, 5.4315f),
            new Rectangle(644.00745f, 121.08f, 6.155998f, 5.4315f),
            new Rectangle(644.00745f, 127.2324f, 7.083f, 5.4315f),
            new Rectangle(644.00745f, 134.3118f, 6.5879974f, 5.4315f),
            new Rectangle(644.00745f, 140.8962f, 6.255005f, 5.4315f),
            new Rectangle(644.00745f, 147.1476f, 6.2819977f, 5.4315f),
            new Rectangle(644.00745f, 153.426f, 5.6880035f, 5.4315f),
            new Rectangle(644.00745f, 159.1104f, 6.156006f, 5.4315f),
            new Rectangle(644.00745f, 165.2628f, 4.0859985f, 5.4315f),
            new Rectangle(644.00745f, 169.3452f, 3.1679993f, 5.4315f),
            new Rectangle(644.00745f, 176.4894f, 6.9389954f, 5.4315f),
            new Rectangle(644.00745f, 183.42479f, 5.4089966f, 5.4315f),
            new Rectangle(644.00745f, 188.83018f, 3.5460052f, 5.4315f),
            new Rectangle(644.00745f, 192.37259f, 5.4089966f, 5.4315f),
            new Rectangle(644.00745f, 197.77798f, 3.1679993f, 5.4315f),
            new Rectangle(644.00745f, 204.98158f, 3.1679993f, 5.4315f),
            new Rectangle(644.00745f, 208.14598f, 5.4629974f, 5.4315f),
            new Rectangle(644.00745f, 213.60538f, 3.8430023f, 5.4315f),
            new Rectangle(644.00745f, 217.44478f, 3.1679993f, 5.4315f),
            new Rectangle(644.00745f, 224.58897f, 6.156006f, 5.4315f),
            new Rectangle(644.00745f, 230.74138f, 7.3619995f, 5.4315f),
            new Rectangle(644.00745f, 238.09978f, 2.4660034f, 5.4315f),
            new Rectangle(644.00745f, 240.61618f, 3.5460052f, 5.4315f),
            new Rectangle(644.00745f, 244.15588f, 4.725006f, 5.4315f),
            new Rectangle(644.00745f, 248.87729f, 5.3639984f, 5.4315f),
            new Rectangle(644.00745f, 254.23769f, 3.8430023f, 5.4315f),
            new Rectangle(644.00745f, 258.0195f, 2.4660034f, 5.4315f),
            new Rectangle(644.00745f, 260.5359f, 5.4089966f, 5.4315f),
            new Rectangle(644.00745f, 265.94128f, 5.696991f, 5.4315f),
            new Rectangle(644.00745f, 271.63467f, 5.6069946f, 5.4315f),
            new Rectangle(644.00745f, 277.23807f, 3.1679993f, 5.4315f),
            new Rectangle(644.00745f, 284.44168f, 5.4089966f, 5.4315f),
            new Rectangle(644.00745f, 289.84708f, 3.842987f, 5.4315f),
            new Rectangle(644.00745f, 293.68646f, 5.3640137f, 5.4315f),
            new Rectangle(644.00745f, 299.04688f, 3.1679993f, 5.4315f),
            new Rectangle(644.00745f, 306.2505f, 5.3640137f, 5.4315f),
            new Rectangle(644.00745f, 311.6109f, 5.328003f, 5.4315f),
            new Rectangle(644.00745f, 316.9353f, 3.54599f, 5.4315f),
            new Rectangle(644.00745f, 320.4777f, 3.842987f, 5.4315f),
            new Rectangle(644.00745f, 324.31708f, 5.4089966f, 5.4315f),
            new Rectangle(644.00745f, 329.72247f, 4.6889954f, 5.4315f),
            new Rectangle(644.00745f, 334.40787f, 3.54599f, 5.4315f),
            new Rectangle(644.00745f, 337.95026f, 5.3640137f, 5.4315f),
            new Rectangle(644.00745f, 343.31067f, 5.6069946f, 5.4315f),
            new Rectangle(644.00745f, 348.91406f, 3.1679993f, 5.4315f),
            new Rectangle(644.00745f, 356.11768f, 3.1679993f, 5.4315f),
            new Rectangle(644.00745f, 359.28207f, 3.842987f, 5.4315f),
            new Rectangle(644.00745f, 363.12146f, 5.4630127f, 5.4315f),
            new Rectangle(644.00745f, 368.58087f, 8.756989f, 5.4315f),
            new Rectangle(644.00745f, 377.33426f, 3.1679993f, 5.4315f),
            new Rectangle(644.00745f, 384.53787f, 3.54599f, 5.4315f),
            new Rectangle(644.00745f, 388.08026f, 5.696991f, 5.4315f),
            new Rectangle(644.00745f, 393.77365f, 5.3640137f, 5.4315f),
            new Rectangle(644.00745f, 399.13406f, 3.1679993f, 5.4315f),
            new Rectangle(644.00745f, 406.2783f, 6.156006f, 5.4315f),
            new Rectangle(644.00745f, 412.4307f, 7.3619995f, 5.4315f),
            new Rectangle(644.00745f, 419.7891f, 2.4660034f, 5.4315f),
            new Rectangle(644.00745f, 422.30548f, 4.6889954f, 5.4315f),
            new Rectangle(644.00745f, 426.99088f, 4.6889954f, 5.4315f),
            new Rectangle(644.00745f, 431.67627f, 3.1679993f, 5.4315f),
            new Rectangle(644.00745f, 438.87988f, 5.174988f, 5.4315f),
            new Rectangle(644.00745f, 444.05127f, 5.3640137f, 5.4315f),
            new Rectangle(644.00745f, 449.41168f, 5.6069946f, 5.4315f),
            new Rectangle(644.00745f, 455.01508f, 5.3640137f, 5.4315f),
            new Rectangle(644.00745f, 460.3755f, 3.842987f, 5.4315f),
            new Rectangle(644.00745f, 464.27786f, 5.4089966f, 5.4315f),
            new Rectangle(644.00745f, 469.68146f, 2.4660034f, 5.4315f),
            new Rectangle(644.00745f, 472.14386f, 3.1679993f, 5.4315f),
            new Rectangle(654.9874f, 121.08f, 6.155998f, 5.4315f),
            new Rectangle(654.9874f, 127.245f, 3.5459976f, 5.4315f),
            new Rectangle(654.9874f, 130.8f, 5.4089966f, 5.4315f),
            new Rectangle(654.9874f, 136.218f, 3.5460052f, 5.4315f),
            new Rectangle(654.9874f, 139.773f, 2.4660034f, 5.4315f),
            new Rectangle(654.9874f, 142.248f, 4.6889954f, 5.4315f),
            new Rectangle(654.9874f, 146.946f, 3.5460052f, 5.4315f),
            new Rectangle(654.9874f, 150.42538f, 2.4660034f, 5.4315f),
            new Rectangle(654.9874f, 152.94179f, 4.6889954f, 5.4315f),
            new Rectangle(654.9874f, 157.63979f, 5.4089966f, 5.4315f),
            new Rectangle(654.9874f, 163.05779f, 2.4660034f, 5.4315f),
            new Rectangle(654.9874f, 165.53279f, 3.1679993f, 5.4315f),
            new Rectangle(654.9874f, 170.99669f, 7.083008f, 5.4315f),
            new Rectangle(654.9874f, 178.08868f, 3.1679993f, 5.4315f),
            new Rectangle(654.9874f, 181.21259f, 3.1679993f, 5.4315f),
            new Rectangle(654.9874f, 184.38959f, 2.4660034f, 5.4315f),
            new Rectangle(654.9874f, 186.8646f, 4.6889954f, 5.4315f),
            new Rectangle(654.9874f, 191.56259f, 5.3639984f, 5.4315f),
            new Rectangle(654.9874f, 196.9356f, 3.276001f, 5.4315f),
            new Rectangle(654.9874f, 200.2206f, 3.1679993f, 5.4315f),
            new Rectangle(654.9874f, 205.6845f, 5.6069946f, 5.4315f),
            new Rectangle(654.9874f, 211.30049f, 5.4089966f, 5.4315f),
            new Rectangle(654.9874f, 216.71849f, 3.5460052f, 5.4315f),
            new Rectangle(654.9874f, 220.27348f, 5.4089966f, 5.4315f),
            new Rectangle(654.9874f, 225.69148f, 3.1679993f, 5.4315f),
            new Rectangle(654.9874f, 231.15538f, 3.1679993f, 5.4315f),
            new Rectangle(654.9874f, 234.33238f, 5.4629974f, 5.4315f),
            new Rectangle(654.9874f, 239.80438f, 3.8430023f, 5.4315f),
            new Rectangle(654.9874f, 243.65639f, 3.1679993f, 5.4315f),
            new Rectangle(654.9874f, 249.12029f, 3.7890015f, 5.4315f),
            new Rectangle(654.9874f, 252.91829f, 4.6890106f, 5.4315f),
            new Rectangle(654.9874f, 257.6163f, 3.842987f, 5.4315f),
            new Rectangle(654.9874f, 261.4683f, 5.4089966f, 5.4315f),
            new Rectangle(654.9874f, 266.8863f, 5.3640137f, 5.4315f),
            new Rectangle(654.9874f, 272.25928f, 2.4660034f, 5.4315f),
            new Rectangle(654.9874f, 274.73428f, 3.1679993f, 5.4315f),
            new Rectangle(654.9874f, 280.19818f, 3.1679993f, 5.4315f),
            new Rectangle(654.9874f, 283.37518f, 3.842987f, 5.4315f),
            new Rectangle(654.9874f, 287.22717f, 5.4630127f, 5.4315f),
            new Rectangle(654.9874f, 292.69916f, 8.756989f, 5.4315f),
            new Rectangle(654.9874f, 301.3203f, 3.1679993f, 5.4315f),
            new Rectangle(654.9874f, 306.7842f, 3.54599f, 5.4315f),
            new Rectangle(654.9874f, 310.3275f, 5.696991f, 5.4315f),
            new Rectangle(654.9874f, 316.02182f, 5.3640137f, 5.4315f),
            new Rectangle(654.9874f, 321.38312f, 3.1679993f, 5.4315f),
            new Rectangle(654.9874f, 326.84702f, 6.282013f, 5.4315f),
            new Rectangle(654.9874f, 333.1263f, 5.3640137f, 5.4315f),
            new Rectangle(654.9874f, 338.4876f, 5.696991f, 5.4315f),
            new Rectangle(654.9874f, 344.18192f, 3.54599f, 5.4315f),
            new Rectangle(654.9874f, 347.72522f, 3.842987f, 5.4315f),
            new Rectangle(654.9874f, 351.62762f, 5.4089966f, 5.4315f),
            new Rectangle(654.9874f, 357.03125f, 2.4660034f, 5.4315f),
            new Rectangle(654.9874f, 359.54764f, 3.1679993f, 5.4315f),
            new Rectangle(654.9874f, 365.01154f, 6.174011f, 5.4315f),
            new Rectangle(654.9874f, 371.18283f, 5.696991f, 5.4315f),
            new Rectangle(654.9874f, 376.87714f, 3.842987f, 5.4315f),
            new Rectangle(654.9874f, 380.71744f, 5.3640137f, 5.4315f),
            new Rectangle(654.9874f, 386.07874f, 5.4089966f, 5.4315f),
            new Rectangle(654.9874f, 391.48505f, 5.696991f, 5.4315f),
            new Rectangle(654.9874f, 397.17935f, 3.1679993f, 5.4315f),
            new Rectangle(654.9874f, 402.64325f, 5.4630127f, 5.4315f),
            new Rectangle(654.9874f, 408.10355f, 3.1679993f, 5.4315f),
            new Rectangle(654.9874f, 411.26886f, 3.1679993f, 5.4315f),
            new Rectangle(654.9874f, 416.73276f, 6.156006f, 5.4315f),
            new Rectangle(654.9874f, 422.88605f, 3.54599f, 5.4315f),
            new Rectangle(654.9874f, 426.42935f, 5.4089966f, 5.4315f),
            new Rectangle(654.9874f, 431.83566f, 3.54599f, 5.4315f),
            new Rectangle(654.9874f, 435.37897f, 2.4660034f, 5.4315f),
            new Rectangle(654.9874f, 437.89536f, 4.6889954f, 5.4315f),
            new Rectangle(654.9874f, 442.57538f, 3.54599f, 5.4315f),
            new Rectangle(654.9874f, 446.11868f, 2.4660034f, 5.4315f),
            new Rectangle(654.9874f, 448.63507f, 4.6889954f, 5.4315f),
            new Rectangle(654.9874f, 453.32138f, 4.6889954f, 5.4315f),
            new Rectangle(654.9874f, 458.0077f, 3.1679993f, 5.4315f),
            new Rectangle(654.9874f, 463.4716f, 5.4630127f, 5.4315f),
            new Rectangle(654.9874f, 468.9319f, 3.1679993f, 5.4315f),
            new Rectangle(654.9874f, 472.0972f, 3.1679993f, 5.4315f),
            new Rectangle(665.9071f, 121.08002f, 3.7890015f, 5.4315f),
            new Rectangle(665.9071f, 124.86272f, 4.6889954f, 5.4315f),
            new Rectangle(665.9071f, 129.54541f, 3.8430023f, 5.4315f),
            new Rectangle(665.9071f, 133.38211f, 5.4089966f, 5.4315f),
            new Rectangle(665.9071f, 138.7848f, 5.3639984f, 5.4315f),
            new Rectangle(665.9071f, 144.1425f, 2.4660034f, 5.4315f),
            new Rectangle(665.9071f, 146.6589f, 3.276001f, 5.4315f),
            new Rectangle(665.9071f, 149.961f, 3.1679993f, 5.4315f),
            new Rectangle(665.9071f, 153.1452f, 5.4089966f, 5.4315f),
            new Rectangle(665.9071f, 158.5479f, 5.697006f, 5.4315f),
            new Rectangle(665.9071f, 164.2386f, 5.6069946f, 5.4315f),
            new Rectangle(665.9071f, 169.8393f, 3.1679993f, 5.4315f),
            new Rectangle(665.9071f, 173.0235f, 5.6069946f, 5.4315f),
            new Rectangle(665.9071f, 178.6242f, 5.4089966f, 5.4315f),
            new Rectangle(665.9071f, 184.0269f, 3.5460052f, 5.4315f),
            new Rectangle(665.9071f, 187.5666f, 5.4089966f, 5.4315f),
            new Rectangle(665.9071f, 192.9693f, 3.1679993f, 5.4315f),
            new Rectangle(665.9071f, 196.1535f, 3.1679993f, 5.4315f),
            new Rectangle(665.9071f, 199.3152f, 5.4629974f, 5.4315f),
            new Rectangle(665.9071f, 204.7719f, 3.8430023f, 5.4315f),
            new Rectangle(665.9071f, 208.6086f, 3.1679993f, 5.4315f),
            new Rectangle(665.9071f, 211.7928f, 6.5879974f, 5.4315f),
            new Rectangle(665.9071f, 218.3745f, 5.697006f, 5.4315f),
            new Rectangle(665.9071f, 224.0652f, 2.4660034f, 5.4315f),
            new Rectangle(665.9071f, 226.5816f, 3.5460052f, 5.4315f),
            new Rectangle(665.9071f, 230.1213f, 5.3639984f, 5.4315f),
            new Rectangle(665.9071f, 235.479f, 5.6069946f, 5.4315f),
            new Rectangle(665.9071f, 241.07971f, 3.1679993f, 5.4315f),
            new Rectangle(665.9071f, 244.26392f, 6.2369995f, 5.4315f),
            new Rectangle(665.9071f, 250.49461f, 2.4660034f, 5.4315f),
            new Rectangle(665.9071f, 253.01102f, 5.696991f, 5.4315f),
            new Rectangle(665.9071f, 258.70172f, 5.6069946f, 5.4315f),
            new Rectangle(665.9071f, 264.30243f, 5.6069946f, 5.4315f),
            new Rectangle(665.9071f, 269.90314f, 5.4630127f, 5.4315f),
            new Rectangle(665.9071f, 275.35983f, 8.756989f, 5.4315f),
            new Rectangle(665.9071f, 284.11053f, 3.1679993f, 5.4315f),
            new Rectangle(665.9071f, 287.29474f, 3.1679993f, 5.4315f),
            new Rectangle(665.9071f, 290.45645f, 3.842987f, 5.4315f),
            new Rectangle(665.9071f, 294.29315f, 5.4630127f, 5.4315f),
            new Rectangle(665.9071f, 299.74985f, 8.756989f, 5.4315f),
            new Rectangle(665.9071f, 308.39972f, 3.1679993f, 5.4315f),
            new Rectangle(665.9071f, 311.58392f, 3.54599f, 5.4315f),
            new Rectangle(665.9071f, 315.12363f, 5.696991f, 5.4315f),
            new Rectangle(665.9071f, 320.81433f, 5.3640137f, 5.4315f),
            new Rectangle(665.9071f, 326.17203f, 3.1679993f, 5.4315f),
            new Rectangle(665.9071f, 329.35623f, 7.083008f, 5.4315f),
            new Rectangle(665.9071f, 336.43292f, 3.1679993f, 5.4315f),
            new Rectangle(665.9071f, 339.59464f, 3.1679993f, 5.4315f),
            new Rectangle(665.9071f, 342.75635f, 2.4660034f, 5.4315f),
            new Rectangle(665.9071f, 345.27182f, 4.6889954f, 5.4315f),
            new Rectangle(665.9071f, 349.95453f, 5.3640137f, 5.4315f),
            new Rectangle(665.9071f, 355.31223f, 3.1679993f, 5.4315f),
            new Rectangle(665.9071f, 358.49643f, 3.1679993f, 5.4315f),
            new Rectangle(665.9071f, 361.65814f, 5.4630127f, 5.4315f),
            new Rectangle(665.9071f, 367.11484f, 3.842987f, 5.4315f),
            new Rectangle(665.9071f, 370.95154f, 3.1679993f, 5.4315f),
            new Rectangle(665.9071f, 374.13574f, 6.7319946f, 5.4315f),
            new Rectangle(665.9071f, 380.86145f, 5.4089966f, 5.4315f),
            new Rectangle(665.9071f, 386.26416f, 3.54599f, 5.4315f),
            new Rectangle(665.9071f, 389.80386f, 2.4660034f, 5.4315f),
            new Rectangle(665.9071f, 392.31934f, 5.4630127f, 5.4315f),
            new Rectangle(665.9071f, 397.77603f, 5.696991f, 5.4315f),
            new Rectangle(665.9071f, 403.46674f, 5.4089966f, 5.4315f),
            new Rectangle(665.9071f, 408.80914f, 2.4660034f, 5.4315f),
            new Rectangle(665.9071f, 411.32462f, 3.1679993f, 5.4315f),
            new Rectangle(665.9071f, 414.44852f, 6.156006f, 5.4315f),
            new Rectangle(665.9071f, 420.5982f, 3.54599f, 5.4315f),
            new Rectangle(665.9071f, 424.1379f, 5.4089966f, 5.4315f),
            new Rectangle(665.9071f, 429.54062f, 3.54599f, 5.4315f),
            new Rectangle(665.9071f, 433.08032f, 2.4660034f, 5.4315f),
            new Rectangle(665.9071f, 435.5958f, 4.6889954f, 5.4315f),
            new Rectangle(665.9071f, 440.2749f, 3.54599f, 5.4315f),
            new Rectangle(665.9071f, 443.75342f, 2.4660034f, 5.4315f),
            new Rectangle(665.9071f, 446.2689f, 4.6889954f, 5.4315f),
            new Rectangle(665.9071f, 450.9516f, 4.6889954f, 5.4315f),
            new Rectangle(665.9071f, 455.6343f, 3.276001f, 5.4315f),
            new Rectangle(665.9071f, 458.90402f, 3.1679993f, 5.4315f),
            new Rectangle(688.82745f, 137.10002f, 5.0130005f, 5.4315f),
            new Rectangle(688.82745f, 142.10312f, 2.4660034f, 5.4315f),
            new Rectangle(688.82745f, 144.61952f, 5.3639984f, 5.4315f),
            new Rectangle(688.82745f, 149.97362f, 4.6889954f, 5.4315f),
            new Rectangle(688.82745f, 154.65271f, 5.697006f, 5.4315f),
            new Rectangle(688.82745f, 160.33981f, 3.5460052f, 5.4315f),
            new Rectangle(688.82745f, 163.87592f, 5.3639984f, 5.4315f),
            new Rectangle(688.82745f, 169.23001f, 5.697006f, 5.4315f),
            new Rectangle(688.82745f, 174.91711f, 4.6889954f, 5.4315f),
            new Rectangle(688.82745f, 179.59622f, 3.5460052f, 5.4315f),
            new Rectangle(688.82745f, 183.13232f, 5.3639984f, 5.4315f),
            new Rectangle(688.82745f, 188.48642f, 2.4660034f, 5.4315f),
            new Rectangle(688.82745f, 191.00282f, 5.697006f, 5.4315f),
            new Rectangle(688.82745f, 196.68993f, 3.1679993f, 5.4315f),
            new Rectangle(688.82745f, 199.87413f, 5.697006f, 5.4315f),
            new Rectangle(688.82745f, 205.56123f, 5.4089966f, 5.4315f),
            new Rectangle(688.82745f, 210.96033f, 4.6889954f, 5.4315f),
            new Rectangle(688.82745f, 215.63943f, 3.1679993f, 5.4315f),
            new Rectangle(688.82745f, 218.82364f, 5.697006f, 5.4315f),
            new Rectangle(688.82745f, 224.51074f, 5.4629974f, 5.4315f),
            new Rectangle(688.82745f, 229.96384f, 3.5460052f, 5.4315f),
            new Rectangle(688.82745f, 233.49994f, 3.1679993f, 5.4315f),
            new Rectangle(688.82745f, 236.68414f, 5.6069946f, 5.4315f),
            new Rectangle(688.82745f, 242.28125f, 5.3639984f, 5.4315f),
            new Rectangle(688.82745f, 247.63535f, 5.3639984f, 5.4315f),
            new Rectangle(688.82745f, 253.03804f, 5.697006f, 5.4315f),
            new Rectangle(688.82745f, 258.73953f, 3.1679993f, 5.4315f),
            new Rectangle(688.82745f, 261.92374f, 2.4660034f, 5.4315f),
            new Rectangle(688.82745f, 264.44012f, 5.696991f, 5.4315f),
            new Rectangle(688.82745f, 270.14163f, 4.6889954f, 5.4315f),
            new Rectangle(688.82745f, 274.76135f, 2.4660034f, 5.4315f),
            new Rectangle(688.82745f, 277.27774f, 5.696991f, 5.4315f),
            new Rectangle(688.82745f, 282.96484f, 5.6069946f, 5.4315f),
            new Rectangle(688.82745f, 288.56195f, 5.3640137f, 5.4315f),
            new Rectangle(688.82745f, 293.91605f, 5.6069946f, 5.4315f),
            new Rectangle(688.82745f, 299.51315f, 3.1679993f, 5.4315f),
            new Rectangle(688.82745f, 302.69736f, 2.4660034f, 5.4315f),
            new Rectangle(688.82745f, 305.21375f, 5.696991f, 5.4315f),
            new Rectangle(688.82745f, 310.91525f, 3.1679993f, 5.4315f),
            new Rectangle(688.82745f, 314.03915f, 3.54599f, 5.4315f),
            new Rectangle(688.82745f, 317.57526f, 5.696991f, 5.4315f),
            new Rectangle(688.82745f, 323.26236f, 5.3640137f, 5.4315f),
            new Rectangle(688.82745f, 328.61646f, 3.1679993f, 5.4315f),
            new Rectangle(688.82745f, 331.80066f, 3.54599f, 5.4315f),
            new Rectangle(688.82745f, 335.33676f, 5.4089966f, 5.4315f),
            new Rectangle(688.82745f, 340.73587f, 5.6069946f, 5.4315f),
            new Rectangle(688.82745f, 346.33298f, 2.4660034f, 5.4315f),
            new Rectangle(688.82745f, 348.84937f, 5.3640137f, 5.4315f),
            new Rectangle(688.82745f, 354.20346f, 4.0859985f, 5.4315f),
            new Rectangle(688.82745f, 358.27957f, 3.1679993f, 5.4315f),
            new Rectangle(688.82745f, 361.46378f, 6.7319946f, 5.4315f),
            new Rectangle(688.82745f, 368.18588f, 5.4630127f, 5.4315f),
            new Rectangle(688.82745f, 373.63898f, 3.1679993f, 5.4315f),
            new Rectangle(688.82745f, 376.82318f, 5.4089966f, 5.4315f),
            new Rectangle(688.82745f, 382.2223f, 5.696991f, 5.4315f),
            new Rectangle(688.82745f, 387.9094f, 4.6889954f, 5.4315f),
            new Rectangle(688.82745f, 392.5885f, 7.3619995f, 5.4315f),
            new Rectangle(688.82745f, 399.9406f, 5.3640137f, 5.4315f),
            new Rectangle(688.82745f, 405.2947f, 3.842987f, 5.4315f),
            new Rectangle(688.82745f, 409.1278f, 4.6889954f, 5.4315f),
            new Rectangle(688.82745f, 413.80692f, 3.1679993f, 5.4315f),
            new Rectangle(688.82745f, 416.99112f, 3.842987f, 5.4315f),
            new Rectangle(688.82745f, 420.82422f, 5.3640137f, 5.4315f),
            new Rectangle(688.82745f, 426.1783f, 4.6889954f, 5.4315f),
            new Rectangle(688.82745f, 430.85742f, 5.3640137f, 5.4315f),
            new Rectangle(688.82745f, 436.21152f, 2.4660034f, 5.4315f),
            new Rectangle(688.82745f, 438.7279f, 5.328003f, 5.4315f),
            new Rectangle(688.82745f, 444.06943f, 5.3640137f, 5.4315f),
            new Rectangle(688.82745f, 449.42352f, 5.6069946f, 5.4315f),
            new Rectangle(688.82745f, 455.02063f, 3.276001f, 5.4315f),
            new Rectangle(688.82745f, 458.32275f, 3.1679993f, 5.4315f),
            new Rectangle(711.8071f, 203.70001f, 5.5440063f, 5.4315f),
            new Rectangle(711.8071f, 209.23412f, 5.4089966f, 5.4315f),
            new Rectangle(711.8071f, 214.63321f, 5.6069946f, 5.4315f),
            new Rectangle(711.8071f, 220.23032f, 2.4660034f, 5.4315f),
            new Rectangle(711.8071f, 222.74582f, 5.3639984f, 5.4315f),
            new Rectangle(711.8071f, 228.09991f, 3.1679993f, 5.4315f),
            new Rectangle(711.8071f, 231.28322f, 5.723999f, 5.4315f),
            new Rectangle(711.8071f, 236.99731f, 5.723999f, 5.4315f),
            new Rectangle(711.8071f, 242.71141f, 3.1679993f, 5.4315f),
            new Rectangle(711.8071f, 245.89471f, 5.723999f, 5.4315f),
            new Rectangle(711.8071f, 251.60881f, 3.1679993f, 5.4315f),
            new Rectangle(711.8071f, 254.79211f, 6.156006f, 5.4315f),
            new Rectangle(711.8071f, 260.9751f, 4.6889954f, 5.4315f),
            new Rectangle(711.8071f, 265.6542f, 4.6889954f, 5.4315f),
            new Rectangle(711.8071f, 270.3333f, 5.696991f, 5.4315f),
            new Rectangle(711.8071f, 276.02042f, 3.842987f, 5.4315f),
            new Rectangle(711.8071f, 279.85352f, 5.4089966f, 5.4315f),
            new Rectangle(711.8071f, 285.25262f, 4.6889954f, 5.4315f),
            new Rectangle(711.8071f, 289.93173f, 5.328003f, 5.4315f),
            new Rectangle(711.8071f, 295.24982f, 3.1679993f, 5.4315f),
            new Rectangle(711.8071f, 298.4331f, 5.4630127f, 5.4315f),
            new Rectangle(711.8071f, 303.8862f, 3.1679993f, 5.4315f),
            new Rectangle(711.8071f, 307.0443f, 3.1679993f, 5.4315f),
            new Rectangle(711.8071f, 310.2276f, 3.54599f, 5.4315f),
            new Rectangle(711.8071f, 313.7637f, 5.696991f, 5.4315f),
            new Rectangle(711.8071f, 319.4508f, 5.3640137f, 5.4315f),
            new Rectangle(711.8071f, 324.8049f, 3.1679993f, 5.4315f),
            new Rectangle(711.8071f, 327.9882f, 4.6889954f, 5.4315f),
            new Rectangle(711.8071f, 332.6673f, 5.696991f, 5.4315f),
            new Rectangle(711.8071f, 338.3544f, 3.842987f, 5.4315f),
            new Rectangle(711.8071f, 342.1875f, 5.328003f, 5.4315f),
            new Rectangle(711.8071f, 347.5056f, 5.3640137f, 5.4315f),
            new Rectangle(711.8071f, 352.8597f, 5.328003f, 5.4315f),
            new Rectangle(711.8071f, 358.1778f, 3.1679993f, 5.4315f),
            new Rectangle(711.8071f, 361.36108f, 3.842987f, 5.4315f),
            new Rectangle(711.8071f, 365.19418f, 5.3640137f, 5.4315f),
            new Rectangle(711.8071f, 370.54828f, 4.6889954f, 5.4315f),
            new Rectangle(711.8071f, 375.2274f, 5.696991f, 5.4315f),
            new Rectangle(711.8071f, 380.9145f, 2.4660034f, 5.4315f),
            new Rectangle(711.8071f, 383.42996f, 3.54599f, 5.4315f),
            new Rectangle(711.8071f, 386.96875f, 4.6889954f, 5.4315f),
            new Rectangle(711.8071f, 391.64786f, 3.1679993f, 5.4315f) };

    @Test
    public void testRemoveSequentialSpaces() throws IOException {
        Page page = UtilsForTesting.getAreaFromFirstPage(
                "src/test/resources/technology/tabula/m27.pdf", 79.2f,
                28.28f, 103.04f, 732.6f);
        BasicExtractionAlgorithm bea = new BasicExtractionAlgorithm();
        Table table = bea.extract(page).get(0);
        List<RectangularTextContainer> firstRow = table.getRows().get(0);

        assertTrue(firstRow.get(1).getText().equals("ALLEGIANT AIR"));
        assertTrue(firstRow.get(2).getText().equals("ALLEGIANT AIR LLC"));
    }

    @Test
    public void testColumnRecognition() throws IOException {
        Page page = UtilsForTesting
                .getAreaFromFirstPage(
                        "src/test/resources/technology/tabula/argentina_diputados_voting_record.pdf",
                        269.875f, 12.75f, 790.5f, 561f);
        BasicExtractionAlgorithm bea = new BasicExtractionAlgorithm();
        Table table = bea.extract(page).get(0);
        UtilsForTesting.assertTableEquals(table, EXPECTED_COLUMN_RECOGNITION);
    }
    
    @Test
    public void testVerticalRulingsPreventMergingOfColumns() throws IOException {
        List<Ruling> rulings = new ArrayList<Ruling>();
        Float[] rulingsVerticalPositions = { 147f, 256f, 310f, 375f, 431f, 504f };
        for (int i = 0; i < 6; i++) {
            rulings.add(new Ruling(255.57f, rulingsVerticalPositions[i], 0, 398.76f - 255.57f));
        }

        Page page = UtilsForTesting.getAreaFromFirstPage(
                "src/test/resources/technology/tabula/campaign_donors.pdf",
                255.57f, 40.43f, 398.76f, 557.35f);
        BasicExtractionAlgorithm bea = new BasicExtractionAlgorithm(rulings);
        Table table = bea.extract(page).get(0);
        List<RectangularTextContainer> sixthRow = table.getRows().get(5);

        assertTrue(sixthRow.get(0).getText().equals("VALSANGIACOMO BLANC"));
        assertTrue(sixthRow.get(1).getText().equals("OFERNANDO JORGE"));
    }

    @Test
    public void testExtractColumnsCorrectly() throws IOException {
        Page page = UtilsForTesting.getAreaFromPage(
                "src/test/resources/technology/tabula/eu-002.pdf", 1,
                115.0f, 70.0f, 233.0f, 510.0f);
        BasicExtractionAlgorithm bea = new BasicExtractionAlgorithm();
        Table table = bea.extract(page).get(0);
        UtilsForTesting.assertTableEquals(table, EXPECTED_CORRECT_COLUMNS);
    }
    
    @Test
    public void testExtractColumnsCorrectly2() throws IOException {
        Page page = UtilsForTesting.getPage("src/test/resources/technology/tabula/eu-017.pdf", 3);
        BasicExtractionAlgorithm bea = new BasicExtractionAlgorithm(page.getVerticalRulings());
        Table table = bea.extract(page.getArea(299.625f, 148.44f, 711.875f, 452.32f)).get(0);
        UtilsForTesting.assertTableEquals(table, EXPECTED_COLUMN_EXTRACTION2);
    }
    
    @Test
    public void testExtractColumnsCorrectly3() throws IOException {
        Page page = UtilsForTesting.getAreaFromFirstPage("src/test/resources/technology/tabula/frx_2012_disclosure.pdf", 
                106.01f, 48.09f, 227.31f, 551.89f);
        BasicExtractionAlgorithm bea = new BasicExtractionAlgorithm();
        Table table = bea.extract(page).get(0);

        UtilsForTesting.assertTableEquals(table, EXPECTED_TABLE_EXTRACTION);

    }
    
    @Test
    public void testCheckSqueezeDoesntBreak() throws IOException {
        Page page = UtilsForTesting.getAreaFromFirstPage("src/test/resources/technology/tabula/12s0324.pdf", 
                99.0f, 17.25f, 316.5f, 410.25f);
        BasicExtractionAlgorithm bea = new BasicExtractionAlgorithm();
        Table table = bea.extract(page).get(0);
        List<List<RectangularTextContainer>> rows = table.getRows();
        List<RectangularTextContainer> firstRow = rows.get(0);
        List<RectangularTextContainer> lastRow = rows.get(rows.size() - 1);
        assertTrue(firstRow.get(0).getText().equals("Violent crime  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  ."));
        assertTrue(lastRow.get(lastRow.size() - 1).getText().equals("(X)"));
    }

    @Test
    public void testNaturalOrderOfRectangles() throws IOException {
        Page page = UtilsForTesting.getPage(
                "src/test/resources/technology/tabula/us-017.pdf", 2)
                .getArea(446.0f, 97.0f, 685.0f, 520.0f);
        BasicExtractionAlgorithm bea = new BasicExtractionAlgorithm(
                page.getVerticalRulings());
        Table table = bea.extract(page).get(0);
        
        List<RectangularTextContainer> cells = table.getCells();
        for (RectangularTextContainer rectangularTextContainer : cells) {
			System.out.println(rectangularTextContainer.getText());
		}
        //Column headers
        assertEquals("Project", cells.get(0).getText());
        assertEquals("Agency", cells.get(1).getText());
        assertEquals("Institution", cells.get(2).getText());

        //First row
        assertEquals("Nanotechnology and its publics", cells.get(3).getText());
        assertEquals("NSF", cells.get(4).getText());
        assertEquals("Pennsylvania State Universit", cells.get(5).getText());
        
        //Second row
        assertEquals("Public information and deliberation in nanoscience and", cells.get(6).getText());
        assertEquals("North Carolina State", cells.get(7).getText());
        assertEquals("Interagency", cells.get(8).getText());
        assertEquals("nanotechnology policy (SGER)", cells.get(9).getText());
        assertEquals("University", cells.get(10).getText());

        //Third row
        assertEquals("Social and ethical research and education in agrifood", cells.get(11).getText());
        assertEquals("NSF", cells.get(12).getText());
        assertEquals("Michigan State University", cells.get(13).getText());
        assertEquals("nanotechnology (NIRT)", cells.get(14).getText());
        
        //Fourth row
        assertEquals("From laboratory to society: developing an informed", cells.get(15).getText());
        assertEquals("NSF", cells.get(16).getText());
        assertEquals("University of South Carolina", cells.get(17).getText());
        assertEquals("approach to nanoscale science and engineering (NIRT)", cells.get(18).getText());
        
        //Fifth row
        assertEquals("Database and innovation timeline for nanotechnology", cells.get(19).getText());
        assertEquals("NSF", cells.get(20).getText());
        assertEquals("UCLA", cells.get(21).getText());
        
        //Sixth row
        assertEquals("Social and ethical dimensions of nanotechnology", cells.get(22).getText());
        assertEquals("NSF", cells.get(23).getText());
        assertEquals("University of Virginia", cells.get(24).getText());
        
        //Seventh row
        assertEquals("Undergraduate exploration of nanoscience,", cells.get(25).getText());
        assertEquals("Michigan Technological", cells.get(26).getText());
        assertEquals("NSF", cells.get(27).getText());
        assertEquals("applications and societal implications (NUE)", cells.get(28).getText());
        assertEquals("University", cells.get(29).getText());
        
        //Eighth row
        assertEquals("Ethics and belief inside the development of", cells.get(30).getText());
        assertEquals("NSF", cells.get(31).getText());
        assertEquals("University of Virginia", cells.get(32).getText());
        assertEquals("nanotechnology (CAREER)", cells.get(33).getText());
        
        //Ninth row
        assertEquals("All centers, NNIN and NCN have a societal", cells.get(34).getText());
        assertEquals("NSF, DOE,", cells.get(35).getText());
        assertEquals("All nanotechnology centers", cells.get(36).getText());
        assertEquals("implications components", cells.get(37).getText());
        assertEquals("DOD, and NIH", cells.get(38).getText());
        assertEquals("and networks", cells.get(39).getText());
          
    }
    
    @Test
    public void testNaturalOrderOfRectanglesOneMoreTime() throws IOException {
        
    	List<Rectangle> rectangles = Arrays.asList(RECTANGLES_TEST_NATURAL_ORDER);
    	Utils.sort(rectangles);
    	
    	for (int i = 0; i < (rectangles.size() - 1); i++) {
			Rectangle rectangle = rectangles.get(i);
			Rectangle nextRectangle = rectangles.get(i + 1);
			
			assertTrue(rectangle.compareTo(nextRectangle) < 0);
			
			
		}

    }

    @Test
    public void testRealLifeRTL2() throws IOException {
        String expectedCsv = UtilsForTesting.loadCsv("src/test/resources/technology/tabula/csv/indictb1h_14.csv");
        Page page = UtilsForTesting.getAreaFromPage("src/test/resources/technology/tabula/indictb1h_14.pdf", 1,
                        205.0f, 120.0f, 622.82f, 459.9f);
        BasicExtractionAlgorithm bea = new BasicExtractionAlgorithm();
        Table table = bea.extract(page).get(0);

        StringBuilder sb = new StringBuilder();
        (new CSVWriter()).write(sb, table);
        assertEquals(expectedCsv, sb.toString());
    }

}
